<?php

namespace App\Console\Commands;

use Illuminate\Console\Command;
use Spatie\Sitemap\SitemapIndex;
use Spatie\Sitemap\Sitemap;
use Spatie\Sitemap\Tags\Sitemap as SitemapTags;
use Spatie\Sitemap\Tags\Url;
use Illuminate\Support\Carbon;
use App\Models\Video;
use App\Models\Category;
use App\Models\Playlist;

class GenerateSitemap extends Command
{

    private SitemapIndex $sitemapIndex;

    private Sitemap $sitemap;

    const SITEMAP_DIR = "sitemaps";

    const SITEMAP_VIDEO = "videos.xml";

    const SITEMAP_CATEGORY = "categories.xml";

    const SITEMAP_PLAYLIST = "playlists.xml";
    /**
     * The name and signature of the console command.
     *
     * @var string
     */
    protected $signature = 'sitemap:generate';

    /**
     * The console command description.
     *
     * @var string
     */
    protected $description = 'Generate the sitemap.';

    /**
     * Create a new command instance.
     *
     * @return void
     */
    public function __construct()
    {
        parent::__construct();
    }

    /**
     * Execute the console command.
     *
     * @return int
     */
    public function handle()
    {
        $this->sitemapIndex = SitemapIndex::create();

        // if sitemap dir not exists then create
        @mkdir(public_path(self::SITEMAP_DIR));


        //generating static pages sitemap

        $this->sitemap = Sitemap::create();





        // generating videos sitemap
        $this->sitemap = Sitemap::create();
        $videos = Video::active()->oldest()->get(['slug', 'updated_at']);
        $videos->each(function ($item) {
            $this->sitemap->add(Url::create(route('video.page', ['slug' => $item->slug]))->setLastModificationDate($item->updated_at));
        });
        $this->sitemap->writeToFile(public_path(self::SITEMAP_DIR . '/' . self::SITEMAP_VIDEO));

        //generating categories sitemap

        $this->sitemap = Sitemap::create();
        $categories = Category::active()->oldest()->withCount('childrens')->get(['slug', 'updated_at']);
        $categories->each(function ($item) {
            if ($item->childrens_count == 0 || $item->childrens_count == null) {
                $this->sitemap->add(Url::create(route('categoryvideos.all', ['slug' => $item->slug]))->setLastModificationDate($item->updated_at));
            } else {
                $this->sitemap->add(Url::create(route('subcategory.all', ['slug' => $item->slug]))->setLastModificationDate($item->updated_at));
            }
        });
        $this->sitemap->writeToFile(public_path(self::SITEMAP_DIR . '/' . self::SITEMAP_CATEGORY));


        //generating categories sitemap

        $this->sitemap = Sitemap::create();
        $playlists = Playlist::active()->oldest()->get(['slug', 'updated_at']);
        $playlists->each(function ($item) {
            $this->sitemap->add(Url::create(route('playlistvideos.all', ['slug' => $item->slug]))->setLastModificationDate($item->updated_at));
        });
        $this->sitemap->writeToFile(public_path(self::SITEMAP_DIR . '/' . self::SITEMAP_PLAYLIST));



        //Sitemap Index created
        $this->sitemapIndex->add(SitemapTags::create(config('app.url') . '/' . self::SITEMAP_DIR . '/' . self::SITEMAP_VIDEO)
            ->setLastModificationDate(now()->today()));
        $this->sitemapIndex->add(SitemapTags::create(config('app.url') . '/' . self::SITEMAP_DIR . '/' . self::SITEMAP_CATEGORY)
            ->setLastModificationDate(now()->today()));
        $this->sitemapIndex->add(SitemapTags::create(config('app.url') . '/' . self::SITEMAP_DIR . '/' . self::SITEMAP_PLAYLIST)
            ->setLastModificationDate(now()->today()));
        $this->sitemapIndex->writeToFile(public_path('/sitemap.xml'));
        $this->info("Successfuly Sitemap Generated!");
    }
}
