<?php

use App\Utils\FrontConst;
use App\Utils\MyConstant;

if (!function_exists('setting')) {

    function setting($name = null, $default = null)
    {
        if (is_null($name)) {
            return app('setting');
        }

        if (is_array($name)) {
            return app('setting')->set($name);
        }

        try {
            return app('setting')->get($name, $default);
        } catch (PDOException $e) {
            return $default;
        }
    }
}

if (!function_exists('isDarkMode')) {
    function isDarkMode()
    {
        return setting(FrontConst::UI_STYLE) == "dark";
    }
}

if (!function_exists('isInlinePlayer')) {
    function isInlinePlayer()
    {
        return setting(MyConstant::INDISPLAY_PLAYER) == "true";
    }
}

if (!function_exists('isAjaxPaging')) {
    /**
     * Check Ajax Paging
     *
     * @return boolean
     */
    function isAjaxPaging()
    {
        return setting(FrontConst::PAGING) != "manual";
    }
}
if (!function_exists('convertShorten')) {
    function convertShorten($n, $precision = 1)
    {
        if ($n < 900) {
            // 0 - 900
            $n_format = number_format($n, $precision);
            $suffix = '';
        } else if ($n < 900000) {
            // 0.9k-850k
            $n_format = number_format($n / 1000, $precision);
            $suffix = 'K';
        } else if ($n < 900000000) {
            // 0.9m-850m
            $n_format = number_format($n / 1000000, $precision);
            $suffix = 'M';
        } else if ($n < 900000000000) {
            // 0.9b-850b
            $n_format = number_format($n / 1000000000, $precision);
            $suffix = 'B';
        } else {
            // 0.9t+
            $n_format = number_format($n / 1000000000000, $precision);
            $suffix = 'T';
        }

        // Remove unecessary zeroes after decimal. "1.0" -> "1"; "1.00" -> "1"
        // Intentionally does not affect partials, eg "1.50" -> "1.50"
        if ($precision > 0) {
            $dotzero = '.' . str_repeat('0', $precision);
            $n_format = str_replace($dotzero, '', $n_format);
        }

        return $n_format . $suffix;
    }
}
