<?php

namespace App\Http\Controllers\Backend\Actions;

use App\Http\Controllers\Controller;
use App\Models\Category;
use App\Models\Page;
use App\Models\Playlist;
use App\Models\User;
use App\Models\Video;
use App\Traits\Response;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Validator;
use Spatie\Permission\Models\Role;

class DeleteController extends Controller
{
    use Response;

    private array $ids = [];

    public function __construct(Request $request)
    {

        $validator = Validator::make($request->all(), [
            'ids' => ['required', 'array']
        ]);

        if ($validator->fails()) {
            return $this->failure(['message' => $validator->errors()->__toString()]);
        }

        $this->ids = $request->input('ids');
    }


    public function deleteVideos()
    {
        if ($count = Video::destroy($this->ids)) {
            return $this->success(['message' => __('message.delete_multiple', ['count' => $count, 'name' => 'Videos'])]);
        }
        return $this->failure();
    }
    public function deleteCategories()
    {
        if ($count = Category::destroy($this->ids)) {
            return $this->success(['message' => __('message.delete_multiple', ['count' => $count, 'name' => 'Videos'])]);
        }

        return $this->failure();
    }
    public function deletePlaylists()
    {
        if ($count = Playlist::destroy($this->ids)) {
            return $this->success(['message' => __('message.delete_multiple', ['count' => $count, 'name' => 'Videos'])]);
        }
        return $this->failure();
    }
    public function deleteUsers()
    {
        if ($count = User::destroy($this->ids)) {
            return $this->success(['message' => __('message.delete_multiple', ['count' => $count, 'name' => 'Videos'])]);
        }
        return $this->failure();
    }

    public function deleteRoles()
    {
        if ($count = Role::destroy($this->ids)) {
            return $this->success(['message' => __('message.delete_multiple', ['count' => $count, 'name' => 'Videos'])]);
        }
        return $this->failure();
    }

    public function deletePages()
    {
        if ($count = Page::destroy($this->ids)) {
            return $this->success(['message' => __('message.delete_multiple', ['count' => $count, 'name' => 'Page'])]);
        }
        return $this->failure();
    }
}
