<?php

namespace App\Http\Controllers\Backend\Home;

use App\Http\Controllers\Controller;
use Carbon\Carbon;
use Illuminate\Http\Request;
use App\Helpers\Helper;
use Hash;
use Illuminate\Support\Facades\Auth;
use App\Http\Requests\Admin\ProfileStore;
use App\Http\Resources\StatisticResource;
use Illuminate\Support\Facades\Http;
use Illuminate\Support\Str;
use App\Models\Video;
use App\Models\Playlist;
use App\Models\VideoView;
use App\Traits\Response;
use Artisan;
use DB;
use Symfony\Component\Console\Output\BufferedOutput;

class DashboardController extends Controller
{
  use Response;
  /**
   * Undocumented function
   */
  public  function __construct()
  {
    $this->middleware("permission:dashboard.index");
  }



  public function index(Request $request)
  {

    $disktot = disk_total_space(public_path());
    $diskfree = disk_free_space(public_path());
    $upload_max = self::file_upload_max_size();

    $data = [
      'server_ip' => $request->server('SERVER_ADDR'),
      'user_ip' => $request->ip(),
      'videos' => Video::count(),
      'playlists' => Playlist::count(),
      'views' => Video::sum('views'),
      'upload' => auth()->user()->videos()->count(),
      'upload_limit' => Helper::formatSize($upload_max),
      'disk_total' => Helper::formatSize($disktot),
      'disk_free' => Helper::formatSize($diskfree),
      'server_date' => Carbon::now()->toDateTimeString()
    ];

    return view('Backend.layouts.index', ['data' => $data]);
  }



  public function profilestore(ProfileStore $request)
  {
    $request->validated();
    $user = Auth::user();
    $user->name = $request->input('name');
    $user->email = $request->input('email');
    if ($request->filled('newpassword')) {
      $user->password = Hash::make($request->input('newpassword'));
    }
    $user->save();
    return redirect()->route('users.editprofile')->with('success', __('message.Update Successfuly'));
  }

  public function profileView()
  {
    return view('Backend.users.profile');
  }


  public function profilechange()
  {
    $user = Auth::user();
    return view('Backend.users.editprofile', compact('user'));
  }


  public function statistics(Request $request)
  {
    $startdate = $request->input('startdate');
    $enddate = $request->input('enddate');

    $statistics = DB::table('analysis')->select('total_views as views', 'created_at')->when(($startdate && $enddate), function ($query) use ($startdate, $enddate) {
      $query->whereBetween('created_at', [now()->parse($startdate), now()->parse($enddate)]);
    })->latest()->limit(7)->get();
    $statistics = $statistics->reverse();
    return $this->success([
      'data' => StatisticResource::collection($statistics)
    ]);
  }

  public function cacheClear()
  {
    $code = -1;
    $output = new BufferedOutput();
    try {

      $code = Artisan::call("cache:clear", [], $output);
    } catch (\Exception $e) {
      logger()->debug($e->getMessage());
    }
    if ($code === 0) {
      return $this->success($output->fetch());
    }
    return $this->failure();
  }

  public function tempImage(Request $request)
  {
    $url = $request->input('url');
    if ($request->filled('url')) {
      $data = Http::get($url);
      if ($data->successful()) {
        $isImage = Str::of($data->header("Content-Type"))->endsWith(['jpg', 'jpeg', 'png', 'gif']);
        if ($isImage) {
          return response($data->body(), 200)->header('Content-Type', $data->header("Content-Type"));
        }
      }
    }
    return $this->failure();
  }





  private static function file_upload_max_size()
  {
    static $max_size = -1;

    if ($max_size < 0) {
      // Start with post_max_size.
      $post_max_size = self::parse_size(ini_get('post_max_size'));
      if ($post_max_size > 0) {
        $max_size = $post_max_size;
      }

      // If upload_max_size is less, then reduce. Except if upload_max_size is
      // zero, which indicates no limit.
      $upload_max = self::parse_size(ini_get('upload_max_filesize'));
      if ($upload_max > 0 && $upload_max < $max_size) {
        $max_size = $upload_max;
      }
    }
    return $max_size;
  }

  private static function parse_size($size)
  {
    $unit = preg_replace('/[^bkmgtpezy]/i', '', $size); // Remove the non-unit characters from the size.
    $size = preg_replace('/[^0-9\.]/', '', $size); // Remove the non-numeric characters from the size.
    if ($unit) {
      // Find the position of the unit in the ordered string which is the power of magnitude to multiply a kilobyte by.
      return round($size * pow(1024, stripos('bkmgtpezy', $unit[0])));
    } else {
      return round($size);
    }
  }
}
