<?php

namespace App\Http\Controllers\Backend\Playlist;

use App\Http\Controllers\Controller;
use App\Models\Playlist;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Validator;
use App\Models\Video;
use App\Traits\Response;
use Illuminate\Database\Eloquent\Builder;

class PlaylistVideoController extends Controller
{
    use Response;

    private Request $request;

    public function __construct(Request $request)
    {
        $this->request = $request;
        $this->middleware('permission:playlists.edit');
    }

    public function addVideoPlaylist()
    {

        $validator = Validator::make($this->request->all(), [
            'playlist_id' => 'required',
            'video_ids' => 'required|array',
        ]);

        if ($validator->fails()) {
            if ($this->request->wantsJson()) {
                return $this->failure(['message' => $validator->errors()->__toString()]);
            }
            return back()->withErrors($validator);
        }
        $playlist = Playlist::findOrfail($this->request->input('playlist_id'));
        $videos = Video::find($this->request->input('video_ids'));
        $playlist->videos()->syncWithoutDetaching($videos);
        if ($this->request->wantsJson()) {
            return $this->success(['message' => __('message.added', ['name' => 'Videos'])]);
        }
        return back()->with('success', __('message.added', ['name' => 'Videos']));
    }

    public function removeVideoPlaylist()
    {
        $validator = Validator::make($this->request->all(), [
            'playlist_id' => 'required',
            'video_ids' => 'required|array',
        ]);

        if ($validator->fails()) {
            return $this->failure(['message' => $validator->errors()->__toString()]);
        }
        $playlist = Playlist::findOrfail($this->request->input('playlist_id'));
        $videos = Video::find($this->request->input('video_ids'));
        $playlist->videos()->detach($videos);
        if ($this->request->wantsJson()) {
            return $this->success(['message' => __('message.removed', ['name' => 'Videos'])]);
        }
        return back()->with('success', __('message.removed', ['name' => 'Playlist Videos']));
    }

    public function videoList()
    {
        $find = $this->request->input('q');
        $videos = Video::select('id', 'title as text')->when($find, function (Builder $query, $find) {
            if (is_numeric($find)) {
                $query->where('id', $find);
            } else {
                $query->where('title', "LIKE", '%' . $find . '%');
            }
        })->get();

        return response()->json(['results' => $videos]);
    }

    public function playlistList()
    {
        $find = $this->request->input('q');
        $playlists = Playlist::select('id', 'name as text')->when($find, function (Builder $query, $find) {
            if (is_numeric($find)) {
                $query->where('id', $find);
            } else {
                $query->where('name', "LIKE", '%' . $find . '%');
            }
        })->get();

        return response()->json(['results' => $playlists]);
    }
}
