<?php

namespace App\Http\Controllers\Backend\Settings;

use Illuminate\Support\Facades\Mail;
use App\Http\Controllers\Controller;
use App\Helpers\Helper;
use App\Http\Requests\SettingUpdateRequest;
use App\Mail\TestMail;
use Artisan;
use Spatie\Image\Image;
use Str;
use Spatie\Image\Manipulations;

class SettingController extends Controller
{

    /**
     * Checking Permissions
     */

    public function __construct()
    {
        $this->middleware('permission:settings.edit');
    }

    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {

        $title = Str::title(request()->query('action', trans('admin.General'))) . ' ' . trans('admin.Settings');
        $settings = setting()->all();
        $timezones = Helper::generate_timezone_list();
        $manipulations_position  = $this->manipulations();
        return view('Backend.settings.index', compact('timezones', 'settings', 'title', 'manipulations_position'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(SettingUpdateRequest $request)
    {

        if ($request->hasFile('logo')) {
            $logoPath = 'images/' . Str::random(4) . '.png';
            $logo = setting('logo');
            if ($logo) {
                @unlink(public_path($logo["path"]));
            }
            Image::load($request->file('logo'))->height(40)->optimize()->save(public_path($logoPath));
            $width = Image::load(public_path($logoPath))->getWidth();
            setting(['logo' => ['path' => $logoPath, 'w' => $width, "h" => 40]]);
        }

        if ($request->hasFile('watermark_image')) {
            $watermark_video = $request->file("watermark_image");
            @mkdir(storage_path('app/images'));
            Image::load($watermark_video)->quality(99)->save(storage_path('app/images/image_watermark.png'));
        }


        if ($request->hasFile('watermark_video')) {
            $watermark_video = $request->file("watermark_video");
            @mkdir(storage_path('app/images'));
            Image::load($watermark_video)->quality(99)->save(storage_path('app/images/video_watermark.png'));
        }

        if ($request->hasFile('icon')) {
            Image::load($request->file('icon'))->height(180)->width(180)->optimize()->save(public_path('images/apple-touch-icon.png'));
            Image::load($request->file('icon'))->height(192)->width(192)->optimize()->save(public_path('images/android-chrome-192x192.png'));
            Image::load($request->file('icon'))->height(512)->width(512)->optimize()->save(public_path('images/android-chrome-512x512.png'));
            Image::load($request->file('icon'))->height(196)->width(196)->optimize()->save(public_path('images/maskable-196x196.png'));
            Image::load($request->file('icon'))->height(32)->width(32)->optimize()->save(public_path('images/favicon-32x32.png'));
            Image::load($request->file('icon'))->height(16)->width(16)->optimize()->save(public_path('images/favicon-16x16.png'));
        }

        if ($request->query('action') == "general" || $request->query('action') == "theme") {
            $manifest = [
                "short_name" => $request->input('app_name') ?: config('app.name'),
                "name" => $request->input('app_name') ?: config('app.name'),
                "icons" => [
                    [
                        "src" => "/images/android-chrome-192x192.png",
                        "type" => "image/png",
                        "sizes" => "192x192"
                    ],
                    [
                        "src" => "/images/android-chrome-512x512.png",
                        "type" => "image/png",
                        "sizes" => "512x512"
                    ],
                    [

                        "src" => "/images/maskable-196x196.png",
                        "sizes" => "196x196",
                        "type" => "image/png",
                        "purpose" => "maskable"
                    ]
                ],
                "id" => "/?homescreen=1",
                "start_url" => "/?homescreen=1",
                "background_color" => $request->input('theme_color', '#6610f2') ?:  '#6610f2',
                "display" => "standalone",
                "scope" => "/",
                "theme_color" => $request->input('theme_color', '#6610f2') ?: '#6610f2',
                "description" => $request->input('meta_description') ?: '',
                "gcm_sender_id" => ''
            ];
            $manifestPath = public_path('manifest.json');
            $fp = fopen($manifestPath, 'w');
            fwrite($fp, json_encode($manifest));
            fclose($fp);
        }

        if ($request->boolean('sendtestmail')) {
            Mail::to(auth()->user())->send(new TestMail);
        }

        setting($request->except('watermark_image', 'watermark_video', '_token', 'action', 'logo', 'icon', '_method', 'sendtestmail'));



        Artisan::call("cache:clear");

        if ($request->query('action') == "routing") {
            Artisan::call("route:cache");
        }
        return redirect()->route("settings.index", ['action' => $request->query('action'), 'update' => true]);
    }

    private function manipulations()
    {

        $data = array();
        $data[Manipulations::POSITION_TOP_LEFT] = "Top Left";
        $data[Manipulations::POSITION_TOP] = "Top Center";
        $data[Manipulations::POSITION_TOP_RIGHT] = "Top Right";
        $data[Manipulations::POSITION_LEFT] = "Left Center";
        $data[Manipulations::POSITION_CENTER] = "Center";
        $data[Manipulations::POSITION_RIGHT] = "Right Center";
        $data[Manipulations::POSITION_BOTTOM_LEFT] = "Bottom Left";
        $data[Manipulations::POSITION_BOTTOM] = "Bottom Center";
        $data[Manipulations::POSITION_BOTTOM_RIGHT] = "Bottom Right";
        return $data;
    }
}
