<?php

namespace App\Http\Controllers\Frontend;

use App\Http\Controllers\Controller;
use App\Http\Requests\InstallerRequest;
use App\Installer\ServerRequirement;
use Symfony\Component\Console\Output\BufferedOutput;
use Butschster\Head\Facades\Meta;
use App\Helpers\Helper;
use App\Http\Middleware\RedirectIfInstalled;
use App\Installer\Application;
use Exception;

class InstallerController extends Controller
{

    public function __construct()
    {
        $this->middleware(RedirectIfInstalled::class);
        Meta::setTitle("Installer");
    }


    public function index()
    {

        Meta::prependTitle("License Agreement");
        return view("installer.index");
    }



    public function requirement(ServerRequirement $requirement)
    {
        if (!request()->filled('agree')) {
            return redirect()->route('installer.index');
        }

        Meta::prependTitle("Overview");
        return view("installer.requirement", compact('requirement'));
    }


    public function configuration(ServerRequirement $requirement)
    {

        if (!$requirement->check()) {
            return redirect()->route("installer.index");
        }

        Meta::prependTitle("Configuration");

        $timezones = Helper::generate_timezone_list();
        return view("installer.configuration", compact('requirement', 'timezones'));
    }

    public function postConfiguration(InstallerRequest $request)
    {
        try {
            Application::checkDB($request->all());
            Application::writeEnv($request->all());
            Application::checkLicense($request);
        } catch (Exception $e) {
            return back()->withInput()
                ->with('error', $e->getMessage());
        }
        return view("installer.finalize");
    }

    public function finish()
    {

        $code = -1;
        $output = new BufferedOutput();
        try {
            $output->writeln(cache()->get("LICENSE_STATUS"));
            $code = Application::runArtisan($output);
        } catch (\Exception $e) {
            $output->writeln($e->getMessage());
            $output->writeln($e->getTraceAsString());
        }
        return view('installer.finish', [
            'success' => $code === 0,
            'output' => $output->fetch()
        ]);
    }
}
