<?php

namespace App\Http\Requests;

use Illuminate\Foundation\Http\FormRequest;

use Illuminate\Validation\Rule;
use App\Utils\FrontConst;

class SettingUpdateRequest extends FormRequest
{
    /**
     * Determine if the user is authorized to make this request.
     *
     * @return bool
     */
    public function authorize()
    {
        return true;
    }

    /**
     * Get the validation rules that apply to the request.
     *
     * @return array
     */
    public function rules()
    {

        if ($this->query('action') == "mail") {
            return [
                'email_driver' => ['required', Rule::in(['smtp', 'sendmail'])],
                'email_from_address' => 'nullable|email',
                'email_encryption' => ['nullable', Rule::in(['ssl', 'tls'])]
            ];
        } else if ($this->query('action') == "theme") {
            return [
                'logo' => 'nullable|image',
                'icon' => 'nullable|image',
                'watermark_image' => 'nullable|image|mimes:png',
                'watermark_video' => 'nullable|image|mimes:png',
            ];
        } else if ($this->query('action') == "ads") {
            return [
                'player_ad_tagurl' => 'nullable|url'
            ];
        } else if ($this->query('action') == "routing") {
            $routes = collect($this->except(FrontConst::PAGING, 'watermark_image', 'watermark_video', 'action', '_token', 'logo', 'icon', '_method', 'sendtestmail'))->filter(function ($value, $key) {
                return  \Str::of($key)->contains('route_');
            });
            return [
                "route_videos_prefix" => ['nullable', Rule::notIn($routes->except('route_videos_prefix')->all())],
                "route_categories_prefix" => ['nullable', Rule::notIn($routes->except('route_categories_prefix')->all())],
                "route_subcategory_prefix" => ['nullable', Rule::notIn($routes->except('route_subcategory_prefix')->all())],
                "route_playlists_prefix" => ['nullable', Rule::notIn($routes->except('route_playlists_prefix')->all())],
                "route_category_videos_prefix" => ['nullable', Rule::notIn($routes->except('route_category_videos_prefix')->all())],
                "route_playlists_videos_prefix" => ['nullable', Rule::notIn($routes->except('route_playlists_videos_prefix')->all())],
                "route_video_by_tags_prefix" => ['nullable', Rule::notIn($routes->except('route_video_by_tags_prefix')->all())],
                "route_top_videos_prefix" => ['nullable', Rule::notIn($routes->except('route_top_videos_prefix')->all())],
                "route_video_page_prefix" => ['nullable', Rule::notIn($routes->except('route_video_page_prefix')->all())],
                "route_search_page_prefix" => ['nullable', Rule::notIn($routes->except('route_search_page_prefix')->all())],

            ];
        } else {
            return [
                'app_name' => 'nullable',
                'default_timezone' => ['required', 'timezone'],
            ];
        }
    }
}
