<?php

namespace App\Http\Resources;
use Illuminate\Http\Resources\Json\JsonResource;
use MyConstant;

class CategoryResource extends JsonResource
{
    /**
     * Transform the resource into an array.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return array|\Illuminate\Contracts\Support\Arrayable|\JsonSerializable
     */
    public function toArray($request)
    {
        return [
            'id' => $this->getKey(),
            'url' => $this->getUrl(),
            'name' => $this->name,
            'media' => [
                'html' => $this->getHtmlRender()
            ],
            'count' => $this->childrens_count ?: $this->videos_count,
            'count_prefix' => $this->countPrefix(),
        ];
    }

    private function countPrefix()
    {
        if ($this->videos_count) {
            return trans('Videos');
        }
        return trans('Category');
    }

    private function getUrl()
    {
        if ($this->count == 0 || $this->count == null) {
            return route('categoryvideos.all', ['slug' => $this->slug]);
        }
        return  route('subcategory.all', ['slug' => $this->slug]);
    }

    private function getHtmlRender()
    {
        if ($media = $this->getFirstMedia(MyConstant::THUMB_COLLECTION)) {
            return  $media->img()->conversion(MyConstant::THUMB)->lazy()->attributes(['class' => 'card-img', 'alt' => $this->name])->toHtml();
        }
        return '<img class="card-img" src="' . asset('images/default.jpg') . '" alt="' . $this->name . '" width="1280" height="720">';
    }
}
