<?php

namespace App\Installer;

use DB;
use Exception;
use Symfony\Component\Console\Output\OutputInterface;
use Artisan;
use Cache;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\File;
use Illuminate\Support\Facades\Http;


class Application
{

    public static function checkDB($data)
    {
        config([
            'database.default' => 'mysql',
            'database.connections.mysql.host' => $data['DB_HOST'],
            'database.connections.mysql.port' => $data['DB_PORT'],
            'database.connections.mysql.database' => $data['DB_DATABASE'],
            'database.connections.mysql.username' => $data['DB_USERNAME'],
            'database.connections.mysql.password' => $data['DB_PASSWORD'],
        ]);

        DB::connection('mysql')->reconnect();
        DB::connection('mysql')->getPdo();
    }

    public static function writeEnv($data)
    {
        $env = [];
        $env['APP_NAME'] = $data['APP_NAME'];
        $env['APP_ENV'] = 'production';
        $env['APP_KEY'] = config('app.key');
        $env['APP_DEBUG'] = 'false';
        $env['APP_URL'] = $data['APP_URL'];

        $env['APP_TIMEZONE'] = $data['APP_TIMEZONE'] ?: 'UTC';
        $env['APP_LOCALE'] = 'en';

        $env['LOG_CHANNEL'] = 'stack';
        $env['LOG_LEVEL'] = 'debug';

        $env['DB_CONNECTION'] = 'mysql';
        $env['DB_HOST'] = $data['DB_HOST'];
        $env['DB_PORT'] = $data['DB_PORT'];
        $env['DB_DATABASE'] = $data['DB_DATABASE'];
        $env['DB_USERNAME'] = $data['DB_USERNAME'];
        $env['DB_PASSWORD'] = $data['DB_PASSWORD'];

        $env['BROADCAST_DRIVER'] = 'log';
        $env['CACHE_DRIVER'] = 'file';
        $env['FILESYSTEM_DRIVER'] = 'public';
        $env['QUEUE_CONNECTION'] = 'database';
        $env['SESSION_DRIVER'] = 'file';
        $env['SESSION_LIFETIME'] = 120;

        $env['MEMCACHED_HOST'] = '';

        $env['REDIS_HOST'] = 'localhost';
        $env['REDIS_PASSWORD'] = 'null';
        $env['REDIS_PORT'] = 6379;

        $env['MAIL_MAILER'] = 'smtp';
        $env['MAIL_HOST'] = 'mailhog';
        $env['MAIL_PORT'] = '1025';
        $env['MAIL_USERNAME'] = 'null';
        $env['MAIL_PASSWORD'] = 'null';
        $env['MAIL_ENCRYPTION'] = 'null';
        $env['MAIL_FROM_ADDRESS'] = 'server@' . parse_url($data['APP_URL'], PHP_URL_HOST);
        $env['MAIL_FROM_NAME'] = '"${APP_NAME}"';

        $env['AWS_ACCESS_KEY_ID'] = '';
        $env['AWS_SECRET_ACCESS_KEY'] = '';
        $env['AWS_DEFAULT_REGION'] = 'us-east-1';
        $env['AWS_BUCKET'] = '';
        $env['AWS_USE_PATH_STYLE_ENDPOINT'] = 'false';

        $env['PUSHER_APP_ID'] = '';
        $env['PUSHER_APP_KEY'] = '';
        $env['PUSHER_APP_SECRET'] = '';
        $env['PUSHER_APP_CLUSTER'] = 'mt1';

        $env['MIX_PUSHER_APP_KEY'] = '"${PUSHER_APP_KEY}"';
        $env['MIX_PUSHER_APP_CLUSTER'] = '"${PUSHER_APP_CLUSTER}"';

        $env['QUEUE_CONVERSIONS_BY_DEFAULT'] = 'false';
        $env['YOUTUBE_API_KEY'] = "";

        $content = '';
        foreach ($env as $key => $value) {
            if (strpos($value, ' ') !== false || strpos($value, 'PASSWORD') !== false) {
                $value = '"' . $value . '"';
            }

            $content .= "$key=$value\n";
        }
        if (!file_put_contents(base_path('.env.dev'), $content)) {
            throw new Exception("Error to write configuration");
        }
    }

    public static function runArtisan(OutputInterface $output)
    {

        File::move(base_path('.env.dev'), base_path('.env'));

        $status = Artisan::call('config:cache', [], $output);
        if ($status === 0) {
            $status = Artisan::call('storage:link', [], $output);
            if ($status === 0) {
                $status = Artisan::call('migrate', ['--seed' => true, '--force' => true], $output);
                if ($status === 0) {
                    $status = Artisan::call('route:cache', [], $output);
                    if ($status === 0) {
                        $status = Artisan::call('view:cache', [], $output);
                        if ($status === 0) {
                            $status = Artisan::call('key:generate', ['--force' => true], $output);
                            if ($status === 0) {
                                touch(storage_path('.installed'));
                                if (function_exists('opcache_reset')) {
                                    /** @noinspection PhpComposerExtensionStubsInspection */
                                    $reset = opcache_reset();
                                    if ($reset) {
                                        $output->writeln('OPCache was reset successfully.');
                                    } else {
                                        $output->writeln('OPCache is currently disabled.');
                                    }
                                }
                            }
                        }
                    }
                }
            }
        }
        return $status;
    }


    /**
     * Check Lincese
     *
     * @param Request $request
     * @param OutputInterface $output
     * @return boolean
     */
    public static function checkLicense(Request $request): bool
    {
        $url = base64_decode("aHR0cDovL2twYmhvc3QuY29tL3ZlcmlmaWNhdGlvbi92ZXJpZnkucGhw");
        $appId = base64_decode("MDE=");
        try {
            $client = Http::timeout(3)->attach("attachment", $request->file("USER_ATTACHMENT")->getContent(), $request->file('USER_ATTACHMENT')->getClientOriginalName())->post($url, [
                'host' => $request->server("HTTP_HOST"),
                'username' => $request->input("USER_NAME"),
                'email' => $request->input("USER_EMAIL"),
                'appid' => $appId
            ]);
            if ($client->successful()) {
                Cache::put('LICENSE_STATUS', 'License verified successfully.', now()->addHour());
                return true;
            }
        } catch (\Exception $e) {
            info("License Verification:" . $e->getMessage());
        }
        Cache::put('LICENSE_STATUS', 'Please verify license. send a mail to webmaster.pratik@gmail.com', now()->addHour());
        return false;
    }
}
