<?php

namespace App\Models;

use Carbon\Carbon;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\MorphOne;
use Illuminate\Database\Eloquent\Builder;
use Illuminate\Database\Eloquent\Relations\MorphTo;
use Str;

class BaseModel extends Model
{
    use HasFactory;

    // protected $with = ['metatags'];

    /**
     * get the value of the created at
     *
     * @param  $date
     * @return string
     */

    public function getUpdatedAtFormatedAttribute()
    {
        return Carbon::parse($this->attributes['updated_at'])->format('M d, y H:i');
    }
    public function getCreatedAtFormatedAttribute()
    {
        return Carbon::parse($this->attributes['created_at'])->format('M d, y H:i');
    }


    public function setOrdAttribute($value)
    {
        $this->attributes['ord'] = is_numeric($value) ? $value : 0;
    }

    /**
     * get Status badge of active
     *
     * @return string
     */


    public function getStatusAttribute(): string
    {
        return $this->attributes['active'] ? '<span class="badge badge-success">Active</span>' : '<span class="badge badge-warning">Deactive</span>';
    }


    public function metatagable(): MorphTo
    {
        return $this->morphTo();
    }


    /**
     * Meta tags
     *
     * @return MorphOne
     */
    public function metatags(): MorphOne
    {

        return $this->morphOne(Metatag::class, 'metatagable');
    }


    /**
     * get Meta title of the model
     *
     * @return string
     */
    public function getMetaTitleAttribute()
    {
        return optional($this->metatags)->title ?: "";
    }

    /**
     * get Meta Desciption of the model
     *
     * @return string
     */
    public function getMetaDescriptionAttribute()
    {
        return optional($this->metatags)->description ?: "";
    }

    /**
     * get Meta keywords of the model
     *
     * @return string
     */
    public function getMetaKeywordsAttribute(): string
    {

        return  optional($this->metatags)->keywords ?: "";
    }

    public function getDesciptionAttribute($value): string
    {
        return Str::remove('<p></p>', $value);
    }

    /**
     * Custom Paginate
     *
     * @param Builder $query
     * @param integer $page
     * @param integer $perPage
     * @param array|null $columns
     */
    public function scopeCustomPaginate(Builder $query, int $page, int $perPage = 12, ?array $columns =  ['*'])
    {
        $offset = ($page * $perPage) - $perPage;
        return $query->skip($offset)->take($perPage)->get($columns);
    }

    public function scopeBySlug(Builder $query, string $slug)
    {
        return $query->where('slug', $slug);
    }
}
