<?php

namespace App\Models;

use Cviebrock\EloquentSluggable\Sluggable;
use Cviebrock\EloquentSluggable\SluggableScopeHelpers;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Cache;

class Page extends BaseModel
{
    use HasFactory;
    use Sluggable;

    /**
     * The attributes that are mass assignable.
     * 
     *
     * @var array
     */

    protected $fillable = ['title', 'url', 'content', 'ord', 'active'];
    /*
    * The attributes that should be cast to native types.
    *
    * @var array
    */

    protected $casts = [
        'ord' => 'integer',
        'active' => 'boolean',
    ];

    public static function getAllList()
    {
        return Cache::rememberForever('pages.all', function () {
            return self::where('active', 1)->orderByDesc('ord')->latest()->get()->mapWithKeys(function ($page) {
                $link = empty($page->url) ? route('page.info', ['slug' => $page->slug]) : $page->url;
                return [$page->title => $link];
            });
        });
    }

    public function sluggable(): array
    {
        return [
            'slug' => [
                'source' => 'title'
            ]
        ];
    }
}
