<?php

namespace App\Models;

use Carbon\Carbon;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Relations\HasMany;
use Illuminate\Foundation\Auth\User as Authenticatable;
use Illuminate\Notifications\Notifiable;
use Spatie\Permission\Traits\HasRoles;

class User extends Authenticatable
{
    use HasFactory, Notifiable, HasRoles;

    /**
     * The attributes that are mass assignable.
     *
     * @var array
     */
    protected $fillable = [
        'name',
        'email',
        'password',
    ];

    /**
     * The attributes that should be hidden for arrays.
     *
     * @var array
     */
    protected $hidden = [
        'password',
        'remember_token',
    ];

    /**
     * The attributes that should be cast to native types.
     *
     * @var array
     */
    protected $casts = [
        'email_verified_at' => 'datetime',
    ];

    /**
     * Get the value of the created at
     */

    public function getCreatedAtAttribute($date)
    {
        return Carbon::parse($date)->format('d M, y H:i');
    }

    /**
     * Get the value of the updated at
     */

    public function getUpdatedAtAttribute($date)
    {
        return Carbon::parse($date)->format('d M, y H:i');
    }

    /**
     * get Videos of the user
     *
     * @return HasMany
     */
    public function videos(): HasMany
    {
        return $this->hasMany(Video::class);
    }

    /**
     * get Playlists of the user
     *
     * @return HasMany
     */
    public function playlists(): HasMany
    {
        return $this->hasMany(Playlist::class);
    }


    public static function getRolesAndPermission()
    {
        return [
            'Dashboard' => [
                'dashboard.index',
                '',
                '',
                '',
            ],
            'Categories' => [
                'category.index',
                'category.create',
                'category.edit',
                'category.delete',
            ],
            'Videos' => [
                'videos.index',
                'videos.create',
                'videos.edit',
                'videos.delete'
            ],
            'Playlists' => [
                'playlists.index',
                'playlists.create',
                'playlists.edit',
                'playlists.delete',
            ],
            'Admin' => [
                'users.index',
                'users.create',
                'users.edit',
                'users.delete',
            ],
            'Role' => [
                'roles.index',
                'roles.create',
                'roles.edit',
                'roles.delete'
            ],
            'Pages' => [
                'pages.index',
                'pages.create',
                'pages.edit',
                'pages.delete'
            ],
            'Settings' => [
                '',
                '',
                'settings.edit',
                '',
            ],
        ];
    }
}
