<?php

namespace App\Models;

use Carbon\Carbon;
use Illuminate\Database\Eloquent\Builder;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use App\Utils\FrontConst;
use Arr;

class VideoView extends Model
{
    use HasFactory;


    protected $fillable = ['video_id', 'views'];

    public function video()
    {
        return $this->belongsTo(Video::class);
    }


    /**
     * Sorting
     *
     * @param Builder $query
     * @param string $sort
     * @param boolean|null $qualify
     * @return Builder
     */
    public function scopeCustomSort(Builder $query, string $sort): Builder
    {
        switch ($sort) {
            case FrontConst::SORT_YESTERDAY:
                $query->whereBetween('created_at', [now()->yesterday(), now()]);
                break;
            case FrontConst::SORT_WEEK:
                $query->whereBetween('created_at', [now()->subWeek(), now()]);
                break;
            case FrontConst::SORT_MONTH:
                $query->whereBetween('created_at', [now()->subMonth(), now()]);
                break;
            case FrontConst::SORT_SEMI:
                $query->whereBetween('created_at', [now()->subMonths(6), now()]);
                break;
            case FrontConst::SORT_ANNUAL:
                $query->whereBetween('created_at', [now()->subYear(), now()]);
                break;
            default:
                //ALL
                break;
        }

        return $query;
    }

    /**
     * get Video Filters
     *
     * @param array|null $parameters
     * @return array
     */
    public static function getFilters(?array $parameters = []): array
    {
        $filters = array();
        $filters[] = ['name' => __('Yesterday'), 'parameters' => Arr::add($parameters, 'sort', FrontConst::SORT_YESTERDAY)];
        $filters[] = ['name' => __('Last 7 Days'), 'parameters' => Arr::add($parameters, 'sort', FrontConst::SORT_WEEK)];
        $filters[] = ['name' => __('Last 30 Days'), 'parameters' => Arr::add($parameters, 'sort', FrontConst::SORT_MONTH)];
        $filters[] = ['name' => __('Last 6 Month'), 'parameters' => Arr::add($parameters, 'sort', FrontConst::SORT_SEMI)];
        $filters[] = ['name' => __('Last 1 Year'), 'parameters' => Arr::add($parameters, 'sort', FrontConst::SORT_ANNUAL)];
        return $filters;
    }
}
