<?php

namespace App\Providers;

use App\Models\Page;
use Illuminate\Support\ServiceProvider;
use Illuminate\Support\Facades\Schema;
use App\Repositories\SettingRepository;
use App\Models\Setting;
use Illuminate\Pagination\Paginator;
use View;


class AppServiceProvider extends ServiceProvider
{
    /**
     * Register any application services.
     *
     * @return void
     */
    public function register()
    {
        if ($this->app->isLocal()) {
            $this->app->register(\Barryvdh\LaravelIdeHelper\IdeHelperServiceProvider::class);
        }
    }

    /**
     * Bootstrap any application services.
     *
     * @return void
     */
    public function boot()
    {
        //
        Paginator::useBootstrap();
        $this->registerSetting();
        $this->setAppName();
        $this->setupAppTimezone();
        $this->setupEmailConfig();
        $this->setupMetas();
        // $this->setupDisk();
        Schema::defaultStringLength(125);
    }

    private function registerSetting()
    {
        $this->app->singleton('setting', function () {
            return new SettingRepository(Setting::getAllCached());
        });
    }

    private function setAppName()
    {
        $appname = setting('app_name') ?: config('app.name');
        $this->app['config']->set('app.name', $appname);
    }

    private function setupAppTimezone()
    {
        $timezone = setting('default_timezone') ?: config('app.timezone');
        date_default_timezone_set($timezone);
        $this->app['config']->set('app.timezone', $timezone);
    }


    private function setupEmailConfig()
    {
        $this->app['config']->set('mail.driver', setting('email_driver'));
        $this->app['config']->set('mail.from.address', setting('email_from_address'));
        $this->app['config']->set('mail.from.name', setting('email_from_name'));
        $this->app['config']->set('mail.host', setting('email_host'));
        $this->app['config']->set('mail.port', setting('email_port'));
        $this->app['config']->set('mail.username', setting('email_username'));
        $this->app['config']->set('mail.password', setting('email_password'));
        $this->app['config']->set('mail.encryption', setting('email_encryption'));
    }

    private function setupMetas()
    {

        $this->app['config']->set('meta_tags.title.default', config('app.name'));
        $this->app['config']->set('meta_tags.description.default', setting('meta_description'));
        $this->app['config']->set('meta_tags.keywords.default', setting('meta_keywords'));
    }

    private function setupDisk()
    {
    }
}
