<?php

namespace App\Providers;

use Illuminate\Auth\Events\Registered;
use Illuminate\Auth\Listeners\SendEmailVerificationNotification;
use Illuminate\Foundation\Support\Providers\EventServiceProvider as ServiceProvider;
use Spatie\MediaLibrary\MediaCollections\Events\MediaHasBeenAdded;
use App\Listeners\MediaVideoConverterListener;
use App\Observers\CategoryObserver;
use App\Models\Category;
use App\Models\Conversion;
use App\Models\Playlist;
use App\Observers\VideoObserver;
use App\Models\Video;
use App\Observers\ConversionObserver;
use App\Observers\PlaylistObserver;
use Spatie\MediaLibrary\Conversions\Events\ConversionHasBeenCompleted;

use App\Listeners\MediaConversionComplete;
use App\Events\VideoViewed;
use App\Listeners\IncrementVideoView;
use App\Models\User;
use App\Observers\UserObserver;

class EventServiceProvider extends ServiceProvider
{
    /**
     * The event listener mappings for the application.
     *
     * @var array
     */
    protected $listen = [
        Registered::class => [
            SendEmailVerificationNotification::class,
        ],
        MediaHasBeenAdded::class => [
            MediaVideoConverterListener::class
        ],
        ConversionHasBeenCompleted::class => [
            MediaConversionComplete::class
        ],

        VideoViewed::class => [
            IncrementVideoView::class
        ]
    ];

    /**
     * Register any events for your application.
     *
     * @return void
     */
    public function boot()
    {
        $this->registerObserver();
    }


    private function registerObserver()
    {
        Category::observe(CategoryObserver::class);
        Video::observe(VideoObserver::class);
        Playlist::observe(PlaylistObserver::class);
        User::observe(UserObserver::class);
    }
}
