<?php

namespace App\Providers;

use Butschster\Head\Facades\PackageManager;
use Butschster\Head\MetaTags\Meta;
use Butschster\Head\Contracts\MetaTags\MetaInterface;
use Butschster\Head\Contracts\Packages\ManagerInterface;
use Butschster\Head\Providers\MetaTagsApplicationServiceProvider as ServiceProvider;
use Butschster\Head\Packages\Package;
use Butschster\Head\MetaTags\Entities\Favicon;
use Route;

class MetaTagsServiceProvider extends ServiceProvider
{
    protected function packages()
    {
        // Create your own packages here


        PackageManager::create("jquery-ui", function (Package $package) {
            $package->addScript('jquery-ui.min.js', asset('js/jquery-ui.min.js'), ['defer']);
        });

        PackageManager::create("scripts", function (Package $package) {
            $package->addScript('jquery.min.js', asset('js/jquery.min.js'), ['defer']);
        });

        PackageManager::create('favicons', function (Package $package) {
            if (file_exists(public_path('favicon.ico'))) {
                $package->addLink('apple-touch-icon', [
                    'rel' => 'apple-touch-icon',
                    'type' => 'image/png',
                    'href' => '/images/apple-touch-icon.png',
                    'sizes' => '180x180'
                ]);
                $sizes = ['16x16', '32x32'];
                foreach ($sizes as $size) {
                    $package->addTag(
                        'favicon.' . $size,
                        new Favicon('/images/favicon-' . $size . '.png', [
                            'sizes' => $size
                        ])
                    );
                }
                $package->setFavicon('/favicon.ico');
                $package->addLink('shortcut-icon', [
                    'rel' => 'shortcut icon',
                    'type' => 'image/x-icon',
                    'href' => '/favicon.ico',
                ]);
            }
        });
    }

    // if you don't want to change anything in this method just remove it
    protected function registerMeta(): void
    {
        $this->app->singleton(MetaInterface::class, function () {
            $meta = new Meta(
                $this->app[ManagerInterface::class],
                $this->app['config']
            );

            // It just an imagination, you can automatically
            // add favicon if it exists


            $meta->setContentType('text/html');
            // This method gets default values from config and creates tags, includes default packages, e.t.c
            // If you don't want to use default values just remove it.
            $meta->initialize();
            $meta->setCanonical(url()->current());
            if (file_exists(public_path('manifest.json'))) {
                $meta->addLink('manifest.json', [
                    'rel' => 'manifest',
                    'href' => '/manifest.json',
                ]);
            }
            $meta->addMeta('theme-color', [
                'name' => 'theme-color',
                'content' => setting('theme_color', '#6610f2')
            ]);

            if (isInlinePlayer() || Route::currentRouteName() == 'video.page') {
                $meta->addScript("plyr.min.js", asset('js/plyr.min.js'));
            }
            return $meta;
        });
    }
}
