<?php

namespace App\Traits;

use Illuminate\Support\Arr;
use App\Models\User;
use Str;

trait Authorizable
{
    /**
     * List of default method names of the Controllers and the related permission.
     */
    private $abilities = [
        'index'     => 'view',
    ];

    /**
     * Override of callAction to perform the authorization before.
     *
     * @param $method
     * @param $parameters
     *
     * @return mixed
     */
    public function callAction($method, $parameters)
    {
        if ($ability = $this->getAbility($method)) {
            $this->authorize($ability);
        }

        return parent::callAction($method, $parameters);
    }

    public function getAbility($method)
    {
        $curRouteName = \Request::route()->getName();
        $isSecure = Arr::get($this->getAbilities(), $curRouteName);
        return $isSecure ? $isSecure : null;
    }

    private function getAbilities()
    {
        $permissions = collect(User::getRolesAndPermission())->flatten()->filter();
        $keyed = $permissions->mapWithKeys(function ($item) {
            return [$item => $item];
        });
        return $keyed->all();
    }

    public function setAbilities($abilities)
    {
        $this->abilities = $abilities;
    }
}
