<?php

namespace App\Traits;

use App\Utils\MyConstant;
use Illuminate\Support\Collection;
use Spatie\MediaLibrary\MediaCollections\Models\Media;

trait VideoUrlHelpers
{
    /**
     * get Play Urls
     *
     * @return Collection
     */
    public function getPlayUrlsAttribute(): Collection
    {
        if (!$this->getEmbedId() && ($link = $this->url)) {
            $sources = array();
            $extension = pathinfo($link, PATHINFO_EXTENSION) ?: MyConstant::MP4_VIDEO_FORMAT;
            $sources[] = [
                'src' => $link,
                'size' => "",
                'type' => "video/" . $extension
            ];
            return collect($sources);
        }

        $videos =  $this->getMedia(MyConstant::VIDEO_COLLECTION);
        return  $videos->map(function (Media $media) {
            return [
                'src' => $media->getUrl(),
                'size' => $media->getCustomProperty('height', ""),
                'width' => $media->getCustomProperty('width'),
                'height' => $media->getCustomProperty('height'),
                'type' => $media->mime_type
            ];
        });
    }

    public function getDownloadsFilesAttribute(): Collection
    {


        $videos =  $this->getMedia(MyConstant::VIDEO_COLLECTION);
        return  $videos->map(function (Media $media) {
            return [
                'uuid' => $media->uuid,
                'size' => $media->getCustomProperty('height', ""),
                'filesize' => $media->getHumanReadableSizeAttribute(),
                'type' => $media->mime_type
            ];
        });
    }

    /**
     * get URL to YouTube Embed URL
     *
     * @return string
     */
    public function getEmbedUrlAttribute(): string
    {

        if (@preg_match('%(?:youtube(?:-nocookie)?\.com/(?:[^/]+/.+/|(?:v|e(?:mbed)?)/|.*[?&]v=)|youtu\.be/)([^"&?/ ]{11})%i', $this->url, $match)) {
            return sprintf("https://www.youtube.com/embed/%s?origin=%s&iv_load_policy=3&modestbranding=1&playsinline=1&showinfo=0&rel=0&enablejsapi=1", $match[1], config('app.url'));
        }

        return $this->url ?: "";
    }
    public function getEmbedId(): array
    {
        if (@preg_match('%(?:youtube(?:-nocookie)?\.com/(?:[^/]+/.+/|(?:v|e(?:mbed)?)/|.*[?&]v=)|youtu\.be/)([^"&?/ ]{11})%i', $this->url, $match)) {
            return ['provider' => 'youtube', 'id' => $match[1]];
        }
        return [];
    }
}
