@extends('Backend.layouts.app')

@section('content')

    <div class="container-fluid">
        <nav aria-label="breadcrumb">
            <ol class="breadcrumb">
                <li class="breadcrumb-item">{!! link_to_route('dashboard', __('admin.Home')) !!}</li>
                <li class="breadcrumb-item">{!! link_to_route('playlists.index', __('admin.Playlists')) !!}</li>
            </ol>
        </nav>
        <div class="card shadow mb-4">
            <div class="card-header">
                <div class="d-flex justify-content-between">
                    <h6 class="m-0 font-weight-bold text-primary"><i class="fas fa-edit"></i>
                        {{ __('admin.edit', ['name' => 'Playlist']) }}</h6>
                </div>
            </div>
            <div class="card-body">
                @if (session('success'))
                    <x-alert type="success" :message="session('success')" />
                @endif
                @if ($errors->any())
                    <x-validation type="danger" :message="$errors->all()" />
                @endif
                
                {!! Form::open(['route' => ['playlists.destroy', 'playlist' => $playlist], 'id' => 'deleteForm', 'method' => 'DELETE']) !!}
                {!! Form::close() !!}
                <div class="d-flex justify-content-between mb-3">
                    <a href="{{ route('playlists.index') }}" class="btn btn-dark"><span class="fas fa-arrow-left"></span>
                        Back</a>
                        @can('playlists.delete')
                        <a href="#" class="btn btn-danger submitDelete"><span class="fas fa-trash"></span> Delete</a>
                        @endcan
                </div>

                {!! Form::model($playlist, ['route' => ['playlists.update', 'playlist' => $playlist], 'files' => true, 'method' => 'PUT']) !!}
                <div class="row">
                    <div class="col-lg-7">
                        <div class="form-group row">
                            {!! Form::label(__('label.Name'), __('label.Name'), ['class' => 'col-md-3 col-form-label']) !!}
                            <div class="col-md-9">
                                {!! Form::text('name', null, ['class' => 'form-control']) !!}
                            </div>
                        </div>

                        <div class="form-group row">
                            {!! Form::label(null, __('label.Thumb'), ['class' => 'col-md-3 col-form-label']) !!}
                            <div class="col-md-9">
                                <div class="input-group">
                                    {!! Form::hidden('thumb_edit', null, ['id' => 'thumb_edit']) !!}
                                    {!! Form::file('thumb', ['style' => 'display:none', 'id' => 'thumb', 'accept' => 'image/*']) !!}
                                    {!! Form::text('thumb_url', null, ['class' => 'form-control', 'data-file' => 'thumb', 'id' => 'thumb_url', 'placeholder' => __('label.Place_thumb')]) !!}
                                    <div class="input-group-append">
                                        <button type="button" value="thumb" id="uploadImage" class="btn btn-primary"><i
                                                class="fas fa-upload"></i></button>
                                        <button type="button" value="thumb" id="editImage" class="btn btn-primary"><i
                                                class="fas fa-edit"></i></button>
                                    </div>
                                </div>
                            </div>
                        </div>

                        <div class="form-group row">
                            {!! Form::label(null, __('label.Description') . ' (<small>Double click to show Editor</small>)', ['class' => 'col-md-3 col-form-label'], false) !!}
                            <div class="col-md-9">
                                {!! Form::textarea('description', null, ['class' => 'form-control htmleditor', 'rows' => 3, false]) !!}
                            </div>
                        </div>

                        <div class="form-group row">
                            {!! Form::label(null, __('label.Status'), ['class' => "col-md-3 col-form-label'"]) !!}
                            <div class="col-md-4">
                                {!! Form::checkbox('active', true, null, ['data-on' => 'Active', 'data-off' => 'Block', 'data-toggle' => 'toggle', 'data-onstyle' => 'success']) !!}
                            </div>
                        </div>

                    </div>
                    <div class="col-lg-5">
                        <div class="form-group row">
                            {!! Form::label(null, __('label.Meta', ['name' => 'Title']), [
    'class' => "col-md-3
                        col-form-label",
]) !!}
                            <div class="col-md-9">
                                {!! Form::text('meta_title', null, ['class' => 'form-control']) !!}
                            </div>
                        </div>

                        <div class="form-group row">
                            {!! Form::label(null, __('label.Meta', ['name' => 'Desciption']), [
    'class' => "col-md-3
                        col-form-label",
]) !!}
                            <div class="col-md-9">
                                {!! Form::textarea('meta_description', null, ['class' => 'form-control', 'rows' => 2]) !!}
                            </div>
                        </div>


                        <div class="form-group row">
                            {!! Form::label(null, __('label.Meta', ['name' => 'Keywords']).' <small>(Optional)</small>', [
    'class' => "col-md-3
                        col-form-label",
                        ],false) !!}
                            <div class="col-md-9">
                                {!! Form::text('meta_keywords', null, ['class' => 'form-control']) !!}
                            </div>
                        </div>


                    </div>
                </div>
                <div class="row justify-content-end">
                    {!! Form::button('<i class="fas fa-check"></i> ' . __('form.Submit'), ['type' => 'submit', 'class' => 'btn btn-primary']) !!}
                </div>
                {!! Form::close() !!}
            </div>
        </div>
    </div>

    <!-- Edit Image Modal-->
    <div class="modal fade" id="ImageEditModal" tabindex="-1" role="dialog" aria-labelledby="ImageEditModalLabel"
        aria-hidden="true">
        <div class="modal-dialog" role="document">
            <div class="modal-content">
                <div class="modal-header">
                    <h5 class="modal-title" id="ImageEditModalLabel"><i class="fas fa-edit"></i> Image Editor</h5>
                    <button class="close" type="button" data-dismiss="modal" aria-label="Close">
                        <span aria-hidden="true">×</span>
                    </button>
                </div>
                <div class="modal-body">
                    <div id="preview_container" class="img-container">
                        <img id="preview_image" data-value="thumb" class="img-fluid"
                            src="{{ $playlist->getFirstMediaUrl(MyConstant::THUMB_COLLECTION) }} "
                            alt="{{ $playlist->name }}" width="100%" crossorigin="anonymous">
                    </div>
                    <div class="row justify-content-center p-2">
                        <div class="btn-group">
                            <button type="button" class="btn btn-dark rotate-left">
                                <span class="fas fa-undo-alt"></span>
                            </button>
                            <button type="button" class="btn btn-dark rotate-right">
                                <span class="fas fa-redo-alt"></span>
                            </button>
                        </div>
                    </div>
                </div>
                <div class="modal-footer">
                    <button type="button" value="thumb" class="btn btn-primary crop"><i class="fas fa-crop-alt"></i>
                        Crop</button>
                </div>
            </div>
        </div>
    </div>

@endsection
