@extends('Backend.layouts.app')
@section('content')
    <div class="container-fluid">
        <nav aria-label="breadcrumb">
            <ol class="breadcrumb">
                <li class="breadcrumb-item">{!! link_to_route('dashboard', __('admin.Home')) !!}</li>
                <li class="breadcrumb-item">{!! link_to_route('playlists.index', __('admin.Playlists')) !!}</li>
            </ol>
        </nav>

        <div class="card shadow mb-4">
            <div class="card-header">
                <div class="d-flex justify-content-between">
                    <h6 class="m-0 font-weight-bold text-primary"><i class="fas fa-info-circle"></i>
                        {{ __('admin.show', ['name' => 'Playlist']) }}
                    </h6>
                </div>
            </div>
            <div class="card-body">
                <div class="row">
                    <div class="col-md-4">
                        <div class="row justify-content-center">
                            @if ($media = $playlist->getFirstMedia(MyConstant::THUMB_COLLECTION))
                                <div class="m-2">
                                    {{ $media->img()->conversion(MyConstant::THUMB)->attributes(['alt' => $playlist->name, 'class' => 'img-thumbnail']) }}
                                </div>
                            @endif
                            <div class="table-responsive">
                                <table class="table table-bordered text-dark">
                                    <thead>
                                        <tr>
                                            <th>Id</th>
                                            <th>Name</th>
                                            <th>Videos</th>
                                            <th>Status</th>
                                        </tr>

                                    </thead>
                                    <tbody>
                                        <tr>
                                            <td>{{ $playlist->id }}</td>
                                            <td>{{ $playlist->name }}</td>
                                            <td>{{ $playlist->videos->count() }}</td>
                                            <td>{!! $playlist->status !!}</td>
                                        </tr>
                                    </tbody>
                                </table>
                            </div>
                        </div>
                        @if ($playlist->description)
                            <div class="show-more text-dark">
                                {!! $playlist->description !!}
                            </div>
                            <button class="show-more-button btn btn-outline-dark btn-sm" data-more-title="Read More"
                                data-less-title="Read Less"><i class="fas fa-angle-down"></i></button>
                        @endif
                        {!! Form::open(['route' => ['playlists.destroy', 'playlist' => $playlist], 'id' => 'deleteForm', 'method' => 'DELETE']) !!}
                        {!! Form::close() !!}

                        <div class="d-flex justify-content-between">
                            <a href="{{ url()->previous() }}" class="btn btn-dark"><span
                                    class="fas fa-arrow-left"></span> Back</a>
                            @can('playlists.edit')
                                <a href="{{ route('playlists.edit', ['playlist' => $playlist]) }}"
                                    class="btn btn-success"><span class="fas fa-edit"></span> Edit</a>
                            @endcan
                            @can('playlists.delete')
                                <a href="#" class="btn btn-danger submitDelete"><span class="fas fa-trash"></span> Delete</a>
                            @endcan
                        </div>
                    </div>

                    @can('playlists.edit')
                        <div class="col-8">
                            {!! Form::open(['route' => 'add.video.playlist', 'method' => 'POST']) !!}
                            {!! Form::hidden('playlist_id', $playlist->getKey()) !!}

                            <div class="row justify-content-center">
                                <div class="col-md-8 my-2">
                                    @if (session('success'))
                                        <x-alert type="success" :message="session('success')" />
                                    @endif
                                    @if ($errors->any())
                                        <x-validation type="danger" :message="$errors->all()" />
                                    @endif
                                    <div class="input-group">
                                        {!! Form::select('video_ids[]', [], null, ['class' => 'form-control addVideoList', 'placeholder' => 'Search Video or Select Video']) !!}
                                        <div class="input-group-append">
                                            {!! Form::submit(__('admin.add', ['name' => 'Video']), ['class' => 'btn btn-primary']) !!}
                                        </div>
                                    </div>
                                </div>
                            </div>
                            {!! Form::close() !!}
                            <div class="table-responsive">
                                <table id="datalist" data-playlist="{{ $playlist->id }}"
                                    style="user-select:none;cursor: pointer;" name="videos"
                                    class="text-dark table nowrap table-bordered playlistsvideos table-hover" width="100%">
                                    <thead>
                                        <tr>
                                            <th>Id</th>
                                            <th>Title</th>
                                            <th>ModifiedAt</th>
                                        </tr>
                                    </thead>
                                </table>
                            </div>
                        </div>
                    @endcan
                </div>
            </div>
        </div>
    </div>

@endsection
@push('styles')
    <link rel="stylesheet"
        href="{{ asset('assets/dashboard/vendor/jquery-contextmenu/dist/jquery.contextMenu.min.css') }}">
@endpush

@push('scripts')
    <script>
        window.app = {
            rowContext: @json($contextmenu)
        }
    </script>
    <script src="{{ asset('assets/dashboard/vendor/jquery-contextmenu/dist/jquery.contextMenu.min.js') }}"></script>
    <script src="{{ asset('assets/dashboard/vendor/jquery-contextmenu/dist/jquery.ui.position.js') }}"></script>
    <script src="{{ asset('assets/dashboard/js/context.js') }}"></script>
@endpush
