@extends('Backend.layouts.app')
@section('content')
    <div class="container-fluid">
        <nav aria-label="breadcrumb">
            <ol class="breadcrumb">
                <li class="breadcrumb-item">{!! link_to_route('dashboard', __('admin.Home')) !!}</li>
                <li class="breadcrumb-item">{!! link_to_route('users.index', __('admin.Users')) !!}</li>
            </ol>
        </nav>

        <div class="row">
            <div class="col-md-4">
                <div class="card shadow mb-4">
                    <div class="card-header">
                        <div class="d-flex justify-content-between">
                            <h6 class="m-0 font-weight-bold text-primary"><i class="fas fa-info-circle"></i>
                                {{ __('admin.show', ['name' => 'User']) }}
                            </h6>
                        </div>
                    </div>
                    <div class="card-body">
                        <div class="row justify-content-center">
                            <div class="table-responsive">
                                <table class="table table-bordered text-dark">
                                    <tbody>
                                        <tr>
                                            <td>Id:</td>
                                            <td>{{ $user->id }}</td>
                                        </tr>
                                        <tr>
                                            <td>Name:</td>
                                            <td>{{ $user->name }}</td>
                                        </tr>
                                        <tr>
                                            <td>Roles:</td>
                                            <td>{{ $user->roles->pluck('name')->implode(', ') }}</td>
                                        </tr>
                                        <tr>
                                            <td>Total Videos: </td>
                                            <td>{{ $user->videos()->count() }}</td>
                                        </tr>
                                        <tr>
                                            <td>RegistedAt</td>
                                            <td>{{ $user->created_at }}</td>
                                        </tr>
                                        <tr>
                                            <td>UpdatedAt</td>
                                            <td>{{ $user->updated_at }}</td>
                                        </tr>
                                    </tbody>
                                </table>
                            </div>
                        </div>
                        {!! Form::open(['route' => ['users.destroy', 'user' => $user], 'id' => 'deleteForm', 'method' => 'DELETE']) !!}
                        {!! Form::close() !!}
                        <div class="d-flex justify-content-between">
                            <a href="{{ url()->previous() }}" class="btn btn-dark"><span
                                    class="fas fa-arrow-left"></span>
                                Back</a>
                            @can('users.edit')
                                <a href="{{ route('users.edit', ['user' => $user]) }}" class="btn btn-success"><span
                                        class="fas fa-edit"></span> Edit</a>
                            @endcan
                            @can('users.delete')
                            <a href="#" class="btn btn-danger submitDelete"><span class="fas fa-trash"></span> Delete</a>
                            @endcan
                        </div>

                    </div>
                </div>
            </div>

        <div class="col-8">
            <div class="card card-body">
                <div class="row justify-content-between mb-2">
                    <h5 class="text-primary ml-2 heading"><i class="fas fa-fw fa-list"></i> {{ __('admin.Videos') }}
                    </h5>
                </div>
                <div class="table-responsive">
                    <table id="datalist" style="user-select:none;cursor: pointer;" name="videos"
                        class="text-dark table nowrap table-bordered uservideos table-hover" width="100%">
                        <thead>
                            <tr>
                                <th>Id</th>
                                <th>Title</th>
                                <th>ModifiedAt</th>
                            </tr>
                        </thead>
                    </table>
                </div>
            </div>
            
        </div>
        </div>
    </div>
@endsection
@push('styles')
    <link rel="stylesheet"
        href="{{ asset('assets/dashboard/vendor/jquery-contextmenu/dist/jquery.contextMenu.min.css') }}">
@endpush

@push('scripts')
    <script>
        window.app = {
            rowContext: @json($contextmenu)
        }
    </script>
    <script src="{{ asset('assets/dashboard/vendor/jquery-contextmenu/dist/jquery.contextMenu.min.js') }}"></script>
    <script src="{{ asset('assets/dashboard/vendor/jquery-contextmenu/dist/jquery.ui.position.js') }}"></script>
    <script src="{{ asset('assets/dashboard/js/context.js') }}"></script>
@endpush
