@extends('Backend.layouts.app')

@section('content')
    <div class="container-fluid">
        <nav aria-label="breadcrumb">
            <ol class="breadcrumb">
                <li class="breadcrumb-item">{!! link_to_route('dashboard', __('admin.Home')) !!}</li>
                <li class="breadcrumb-item">{!! link_to_route('videos.index', __('admin.Videos')) !!}</li>
            </ol>
        </nav>
        <div class="card shadow mb-4">
            <div class="card-header">
                <div class="d-flex justify-content-between">
                    <h6 class="m-0 font-weight-bold text-primary"><i class="fas fa-file-video"></i>
                        {{ __('admin.add', ['name' => 'Video']) }}</h6>
                </div>
            </div>
            <div class="card-body">
                @if (session('success'))
                    <x-alert type="success" :message="session('success')" />
                @endif
                @if ($errors->any())
                    <x-validation type="danger" :message="$errors->all()" />
                @endif
                {!! Form::open(['route' => 'videos.store', 'files' => true]) !!}
                <div class="row">
                    <div class="col-lg-7">
                        <div class="form-group row">
                            {!! Form::label(null, __('label.File'), [
    'class' => "col-md-3
                        col-form-label",
]) !!}
                            <div class="col-md-9">
                                <div class="input-group">
                                    {!! Form::hidden('fmdir', 'tmp', ['id' => 'fmDir']) !!}
                                    {!! Form::hidden('file_path', null, ['id' => 'file_path']) !!}
                                    {!! Form::text('file_url', null, ['class' => 'form-control', 'data-file' => 'file', 'id' => 'file_url', 'placeholder' => __('label.file_holder')]) !!}
                                    <div class="input-group-append">
                                        <button type="button" value="file" id="largeFileUploader"
                                            data-href="{{ route('upload.uploader') }}" class="btn btn-danger"><i
                                                class="fas fa-upload"></i></button>

                                    </div>
                                </div>
                                <div class="mt-1 copy-file-display">{!! Form::checkbox('copyfile', true, true, ['data-toggle' => 'toggle', 'data-onstyle' => 'warning', 'data-size' => 'xs', 'id' => 'copy_file_server']) !!} <small>Copy file to
                                        server</small>
                                </div>

                                <div id="progress" style="display: none">
                                    <hr>
                                    <div style="height: 25px;" class="progress mb-3">
                                        <div class="progress-bar progress-bar-striped progress-bar-animated"
                                            role="progressbar" aria-valuenow="75" aria-valuemin="0" aria-valuemax="100"
                                            style="width: 75%; height: 100%">75%
                                        </div>
                                    </div>
                                    <p class="text-center mb-0 progressStatus"></p>
                                </div>

                            </div>
                        </div>


                        <div class="form-group row">
                            {!! Form::label(null, __('label.Title'), [
    'class' => "col-md-3
                        col-form-label",
]) !!}
                            <div class="col-md-9">
                                {!! Form::text('title', null, ['class' => 'form-control autosuggest', 'id' => 'file_name']) !!}
                            </div>
                        </div>

                        <div class="form-group row">
                            {!! Form::label(null, __('label.Thumb'), [
    'class' => "col-md-3
                        col-form-label",
]) !!}
                            <div class="col-md-9">
                                <div class="input-group">
                                    {!! Form::hidden('thumb_edit', null, ['id' => 'thumb_edit']) !!}
                                    {!! Form::file('thumb', ['style' => 'display:none', 'id' => 'thumb', 'accept' => 'image/*']) !!}
                                    {!! Form::text('thumb_url', null, ['class' => 'form-control', 'data-file' => 'thumb', 'id' => 'thumb_url', 'placeholder' => __('label.Place_thumb')]) !!}
                                    <div class="input-group-append">
                                        <button type="button" value="thumb" id="uploadImage" class="btn btn-secondary"><i
                                                class="fas fa-upload"></i></button>
                                        <button type="button" value="thumb" id="editImage" class="btn btn-secondary"><i
                                                class="fas fa-edit"></i></button>
                                    </div>
                                </div>
                            </div>
                        </div>

                        <div class="form-group row">
                            {!! Form::label('category_id', __('label.select', ['name' => 'Category']), [
    'class' => "col-md-3
                        col-form-label",
]) !!}
                            <div class="col-md-9">
                                {!! Form::select('category_id', $categories, [], ['class' => 'form-control', 'id' => 'category_id', 'placeholder' => __('label.select', ['name' => 'Category'])]) !!}
                            </div>
                        </div>

                        <div class="form-group row">
                            {!! Form::label(
    null,
    __('label.Description'),
    [
        'class' => "col-md-3
                        col-form-label",
    ],
    false,
) !!}
                            <div class="col-md-9">
                                {!! Form::textarea('description', null, ['class' => 'form-control htmleditor', 'rows' => 3]) !!}
                            </div>
                        </div>

                        <div class="form-group row">
                            {!! Form::label(null, __('label.Tags'), [
    'class' => "col-md-3
                        col-form-label",
]) !!}
                            <div class="col-md-9">
                                {!! Form::text('tags', null, ['class' => 'form-control tagin']) !!}
                            </div>
                        </div>




                        <div class="form-group row">
                            {!! Form::label('datetimepicker', 'Published At', ['class' => "col-md-3 col-form-label'"]) !!}
                            <div class="col-md-4">
                                {!! Form::text('published_at', now()->format('Y-m-d H:i'), ['class' => 'form-control', 'id' => 'datetimepicker']) !!}
                            </div>
                        </div>


                        <div class="form-group row">
                            {!! Form::label(null, 'Visibility', ['class' => "col-md-3 col-form-label'"]) !!}
                            <div class="col-md-4">
                                {!! Form::checkbox('active', true, true, ['data-on' => 'Public', 'data-off' => 'Private', 'data-toggle' => 'toggle', 'data-onstyle' => 'success']) !!}
                            </div>
                        </div>

                    </div>
                    <div class="col-lg-5">
                        {{-- Other --}}

                        <div class="form-group row">
                            {!! Form::label(null, __('label.Meta', ['name' => 'Title']), [
    'class' => "col-md-3
                        col-form-label",
]) !!}
                            <div class="col-md-9">
                                {!! Form::text('meta_title', null, ['class' => 'form-control']) !!}
                            </div>
                        </div>


                        <div class="form-group row">
                            {!! Form::label(null, __('label.Meta', ['name' => 'Description']), [
    'class' => "col-md-3
                        col-form-label",
]) !!}
                            <div class="col-md-9">
                                {!! Form::textarea('meta_description', null, ['class' => 'form-control', 'rows' => 2]) !!}
                            </div>
                        </div>


                        <div class="form-group row">
                            {!! Form::label(
    null,
    __('label.Meta', ['name' => 'Keywords']) . ' <small>(Optional)</small>',
    [
        'class' => "col-md-3
                                                col-form-label",
    ],
    false,
) !!}
                            <div class="col-md-9">
                                {!! Form::text('meta_keywords', null, ['class' => 'form-control']) !!}
                            </div>
                        </div>

                        <div class="form-group row converter-display">
                            {!! Form::label(
    null,
    __('label.conversion', ['name' => 'Video']) .
        ' <small>(FFMPEG
                            Required)</small>',
    ['class' => "col-md-3 col-form-label'"],
    false,
) !!}
                            <div class="col-md-9">
                                {!! Form::checkbox('converter', true, false, ['data-on' => 'YES', 'data-off' => 'NO', 'data-toggle' => 'toggle', 'data-onstyle' => 'info']) !!}
                            </div>
                        </div>



                        <div class="form-group row downloadable-display">
                            {!! Form::label(null, __('label.Downloadable'), ['class' => "col-md-4 col-form-label'"]) !!}
                            <div class="col-md-6">
                                {!! Form::checkbox('is_download', true, true, ['id' => 'downloadbletoggle', 'data-on' => 'YES', 'data-off' => 'NO', 'data-toggle' => 'toggle', 'data-onstyle' => 'danger']) !!}
                            </div>
                        </div>

                        <div class="form-group row">
                            {!! Form::label(null, __('label.Featured'), ['class' => "col-md-4 col-form-label'"]) !!}
                            <div class="col-md-6">
                                {!! Form::checkbox('featured', true, false, ['data-on' => 'YES', 'data-off' => 'NO', 'data-toggle' => 'toggle', 'data-onstyle' => 'warning']) !!}
                            </div>
                        </div>



                    </div>
                </div>
                <div class="row justify-content-end">
                    {!! Form::button('<i class="fas fa-check"></i> ' . __('form.Submit'), [
    'type' => 'submit',
    'class' => 'btn
                btn-primary',
]) !!}
                </div>
                {!! Form::close() !!}
            </div>
        </div>
    </div>

    <!-- Edit Image Modal-->
    <div class="modal fade" id="ImageEditModal" tabindex="-1" role="dialog" aria-labelledby="ImageEditModalLabel"
        aria-hidden="true">
        <div class="modal-dialog" role="document">
            <div class="modal-content">
                <div class="modal-header">
                    <h5 class="modal-title" id="ImageEditModalLabel"><i class="fas fa-edit"></i> Image Editor</h5>
                    <button class="close" type="button" data-dismiss="modal" aria-label="Close">
                        <span aria-hidden="true">x</span>
                    </button>
                </div>
                <div class="modal-body">
                    <div id="preview_container" class="img-container">
                        <img id="preview_image" data-value="thumb" class="img-fluid" src="" alt="" width="100%"
                            crossorigin="anonymous">
                    </div>
                    <div class="row justify-content-center p-2">
                        <div class="btn-group">
                            <button type="button" class="btn btn-dark rotate-left">
                                <span class="fas fa-undo-alt"></span>
                            </button>
                            <button type="button" class="btn btn-dark rotate-right">
                                <span class="fas fa-redo-alt"></span>
                            </button>
                        </div>
                    </div>
                </div>
                <div class="modal-footer">
                    <button type="button" value="thumb" class="btn btn-primary crop"><i class="fas fa-crop-alt"></i>
                        Crop</button>
                </div>
            </div>
        </div>
    </div>
@endsection

@push('styles')
    <link rel="stylesheet" href="{{ asset('assets/dashboard/vendor/tagin/dist/tagin.min.css') }}">
    <link rel="stylesheet" href="{{ asset('assets/dashboard/vendor/gijgo/css/gijgo.min.css') }}">
@endpush

@push('scripts')
    <script src="{{ asset('assets/dashboard/vendor/tagin/dist/tagin.min.js') }}"></script>
    <script src="{{ asset('assets/dashboard/vendor/gijgo/js/gijgo.min.js') }}" type="text/javascript"></script>
    <script>
        window.uploads = {
            maxFiles: 1,
            chunkSize: {{ setting('uploads_chunksize', 2) ?: 2 }} * 1024 * 1024
        }
        $('#datetimepicker').datetimepicker({
            format: 'yyyy-mm-dd HH:MM',
            uiLibrary: 'bootstrap4',
            modal: false,
            footer: true
        });

        const tagin = new Tagin(document.querySelector('.tagin'), {
            enter: true
        })
    </script>
@endpush
