@extends('Backend.layouts.app')
@section('content')
    <div class="container-fluid">
        <nav aria-label="breadcrumb">
            <ol class="breadcrumb">
                <li class="breadcrumb-item">{!! link_to_route('dashboard', __('admin.Home')) !!}</li>
                <li class="breadcrumb-item">{!! link_to_route('videos.index', __('admin.Videos')) !!}</li>
            </ol>
        </nav>

        <div class="row justify-content-center">
            <div class="col-md-8">
                <div class="card shadow mb-4">
                    <div class="card-header">
                        <div class="d-flex justify-content-between">
                            <h6 class="m-0 font-weight-bold text-primary"><i class="fas fa-info-circle"></i>
                                {{ __('admin.show', ['name' => 'Video']) }}
                            </h6>
                        </div>
                    </div>
                    <div class="card-body">
                        <div class="d-flex flex-wrap flex-md-nowrap justify-content-center">
                            <div class="table-responsive">
                                <table class="table table-bordered text-dark">
                                    <tbody>
                                        <tr>
                                            <td colspan="2">
                                                <div class="videoPlayer">
                                                    @if ($video->play_urls->isNotEmpty())
                                                        <video class="player ratio ratio-16x9" id="videoplayer" playsinline
                                                            controls preload="none" data-poster="{{ $poster }}"
                                                            data-plyr-config='@json($playerConfig)'>
                                                            @foreach ($video->play_urls as $conversion)
                                                                <source src="{{ $conversion['src'] }}"
                                                                    size="{{ $conversion['size'] }}"
                                                                    type="{{ $conversion['type'] }}" />
                                                            @endforeach
                                                        </video>
                                                    @else
                                                        <div class="player ratio ratio-16x9" id="videoplayer">
                                                            <iframe src="{{ $video->embed_url }}" allowfullscreen
                                                                allowtransparency></iframe>
                                                        </div>
                                                    @endif
                                                </div>
                                            </td>
                                        </tr>
                                        <tr>
                                            <td>Id:</td>
                                            <td>{{ $video->id }}</td>
                                        </tr>
                                        <tr>
                                            <td>Title:</td>
                                            <td>{{ $video->title }}</td>
                                        </tr>
                                        @if ($video->category_id)
                                            <tr>
                                                <td>Category:</td>
                                                <td>{{ $video->category_name }}</td>
                                            </tr>
                                        @endif

                                        <tr>
                                            <td>Visibility:</td>
                                            <td> {!! $video->active_status !!}
                                            </td>
                                        </tr>

                                        <tr>
                                            <td>Featured:</td>
                                            <td>
                                                @if ($video->featured)
                                                    <span class="badge badge-success">Featured</span>
                                                @else
                                                    <span class="badge badge-warning">Not Featured</span>
                                                @endif
                                            </td>
                                        </tr>

                                        <tr>
                                            <td>Uploaded Status:</td>
                                            <td>
                                                {!! $video->upload_status !!}
                                            </td>
                                        </tr>

                                        @if ($video->youtube_id)
                                            <tr>
                                                <td>YouTube:</td>
                                                <td>
                                                    {!! link_to('https://www.youtube.com/watch?v=' . $video->youtube_id, $video->youtube_id, ['target' => '_blank']) !!}</td>
                                            </tr>
                                        @endif
                                        <tr>
                                            <td>Uploaded:</td>
                                            <td>
                                                {!! link_to_route('users.show', $video->user_name, ['user' => $video->user_id]) !!}

                                            </td>
                                        </tr>

                                        <tr>
                                            <td>Views:</td>
                                            <td>
                                                Today: <strong>{{ $video->today_views }}</strong>
                                                Lifetime: <strong>{{ $video->views }}</strong>

                                            </td>
                                        </tr>

                                        <tr>
                                            <td>Likes & Unlikes:</td>
                                            <td>
                                                Likes: <strong>{{ $video->likes }}</strong>
                                                Unlikes: <strong>{{ $video->unlikes }}</strong>

                                            </td>
                                        </tr>


                                        @if ($video->tags)
                                            <tr>
                                                <td>Tags:</td>
                                                <td><small>{{ $video->tags }}</small></td>
                                            </tr>
                                        @endif

                                        <tr>
                                            <td>PublishAt:</td>
                                            <td> {!! $video->published_at_status !!}
                                            </td>
                                        </tr>

                                        <tr>
                                            <td>CreatedAt:</td>
                                            <td> {!! $video->created_at !!}
                                            </td>
                                        </tr>

                                        <tr>
                                            <td>UpdatedAt:</td>
                                            <td> {!! $video->updated_at !!}
                                            </td>
                                        </tr>
                                    </tbody>
                                </table>
                            </div>
                        </div>
                        @if ($video->description)
                            <div class="show-more text-dark">
                                {!! $video->description !!}
                            </div>
                            <button class="show-more-button btn btn-outline-dark btn-sm" data-more-title="Read More"
                                data-less-title="Read Less"><i class="fas fa-angle-down"></i></button>
                        @endif
                        {!! Form::open(['route' => ['videos.destroy', 'video' => $video], 'id' => 'deleteForm', 'method' => 'DELETE']) !!}
                        {!! Form::close() !!}
                        <div class="d-flex justify-content-between">
                            <a href="{{ url()->previous() }}" class="btn btn-dark"><span
                                    class="fas fa-arrow-left"></span>
                                Back</a>
                            @can('videos.edit')
                                <a href="{{ route('videos.edit', ['video' => $video]) }}" class="btn btn-success"><span
                                        class="fas fa-edit"></span> Edit</a>
                            @endcan
                            @can('videos.delete')
                                <a href="#" class="btn btn-danger submitDelete"><span class="fas fa-trash"></span> Delete</a>
                            @endcan
                        </div>

                    </div>
                </div>
            </div>
        </div>
    </div>

@endsection

@push('styles')
    <link rel="stylesheet" href="{{ asset('css/player.css') }}">
@endpush
@push('scripts')
    <script src="{{ asset('js/plyr.min.js') }}"></script>
    <script>
        document.addEventListener('DOMContentLoaded', () => {
            new Plyr("#videoplayer", {
                loadSprite: true,
                ratio: "16:9",
                iconUrl: "{{ asset('static/plyr.svg') }}",
                blankVideo: "{{ asset('static/blank.mp4') }}",
                quality: @json(FrontConst::PLAYER_DEFAULT_QUALITY),
            });
        });
    </script>
@endpush
