@extends('Frontend.layouts.app')

@section('head')
    @if ($schema)
        <script type="application/ld+json">
            @json($schema)
        </script>
    @endif
@endsection

@section('content')
    <div class="container-fluid">
        <div class="row">
            <main class="col-lg-8">
                <section id="videoInfo">
                    <div class="videoPlayer">
                        <video class="player ratio ratio-16x9" id="myplayer" playsinline controls preload="none"
                            data-poster="{{ $poster }}" data-plyr-config='@json($playerConfig)'>
                        </video>
                    </div>
                    {!! setting('ad_video_player_after') !!}
                    <div class="v-info">
                        @if ($video->tags_list)
                            <ul class="tags">
                                @foreach ($video->tags_list as $key => $tag)
                                    <li><a href="{{ route('tags.all', ['slug' => Str::slug($tag)]) }}"
                                            class="tag-link">{{ $tag }}</a></li>
                                @endforeach
                            </ul>
                        @endif
                        <h1 class="title">{{ $video->title }}</h1>
                        <div class="d-flex flex-wrap info">
                            <p class="views">{{ $video->views }} {{ __('Views') }}</p>
                            <p class="posted">{{ __('Published') }} {{ $video->published }}</p>
                            @if ($video->category)
                                <p class="ms-2"><i class="fa fa-folder-open" aria-hidden="true"></i> <a
                                        class="text-warning"
                                        href="{{ route('categoryvideos.all', ['slug' => $video->category->slug]) }}">{{ $video->category->name }}</a>
                                </p>
                            @endif
                        </div>
                        <div class="row justify-content-center">
                            <div class="col-md-8">
                                <div class="secondary-nav mt-1 v-options">
                                    <a href="#" class="nav-link like" data-id="{{ $video->getKey() }}"
                                        data-href="{{ route('video.like', ['slug' => $video->slug]) }}" role="button">
                                        <i class="fa fa-thumbs-up" aria-hidden="true"></i>
                                        <span class="title">{{ convertShorten($video->likes) }}</span>
                                    </a>

                                    <a href="#" class="nav-link unlike" data-id="{{ $video->getKey() }}"
                                        data-href="{{ route('video.unlike', ['slug' => $video->slug]) }}" role="button">
                                        <i class="fa fa-thumbs-down" aria-hidden="true"></i>
                                        <span class="title">@lang('Dislike')</span>
                                    </a>

                                    <a href="#" class="nav-link sharebutton" role="button">
                                        <i class="fa fa-share" aria-hidden="true"></i>
                                        <span class="title">{{ __('Share') }}</span>
                                    </a>
                                    @if ($video->is_download && !$video->getEmbedId())
                                        @if ($video->url)
                                            <a href="#" data-href="{{ $video->url }}" class="nav-link openlink"
                                                role="button">
                                                <i class="fa fa-download" aria-hidden="true"></i>
                                                <span class="title">{{ __('Download') }}</span>
                                            </a>
                                        @else
                                            <a href="#"
                                                data-href="{{ route('video.downloads', ['slug' => $video->slug]) }}"
                                                class="nav-link downButton" role="button">
                                                <i class="fa fa-download" aria-hidden="true"></i>
                                                <span class="title">{{ __('Download') }}</span>
                                            </a>
                                        @endif
                                    @endif
                                </div>
                            </div>
                        </div>
                        <hr>
                        @if ($video->description)
                            <div id="article">
                                <div class="show-more">
                                    {!! $video->description !!}
                                </div>
                                <div class="text-center">
                                    <a href="#" role="button" class="show-more-button"
                                        data-more-title="{{ __('Read More') }}"
                                        data-less-title="{{ __('Read Less') }}"><i class="fa fa-angle-down"
                                            aria-hidden="true"></i><span class="visually-hidden">Read
                                            More</span></a>
                                </div>
                            </div>
                        @endif
                        {!! setting('ad_video_info_after') !!}
                    </div>
                </section>
                @if ($playlists->isNotEmpty())
                    <section id="reletedplaylist">
                        <div class="section-title">
                            <h2><span>{{ __('Releted Playlist') }}</span></h2>
                        </div>
                        <x-playlist-grid :playlists="$playlists" class="row row-cols-2 row-cols-sm-3 g-2 g-sm-4" />
                    </section>
                @endif
            </main>
            <aside class="col-lg-4">
                {!! setting('ad_sidebar_before') !!}
                <section id="reletedvideos">
                    <div class="section-title">
                        <h2><span> {{ __('Releted Videos') }}</span></h2>
                    </div>
                    <x-video-list :videos="$reletedvideos" class="row-cols-1 g-2" />
                    @if (isAjaxPaging() && $reletedvideos->isNotEmpty())
                        <div id="pagination" class="d-flex justify-content-center my-2" data-page="0"
                            data-href="{{ route('video.releted', ['slug' => $video->slug]) }}">
                            @if (setting(FrontConst::PAGING) == 'infinite-scroll')
                                <div id="loader" class="spinner-border text-primary" style="display: none"
                                    data-type="scroll" role="status">
                                    <span class="visually-hidden">{{ trans('Loading...') }}</span>
                                </div>
                            @else
                                <button id="loader" role="button" type="button"
                                    class="btn btn-primary">{{ trans('Load More') }}</button>
                            @endif
                        </div>
                    @endif
                </section>
            </aside>
        </div>
    </div>
    <div class="modal fade" id="modalDialog" tabindex="-1" aria-labelledby="modalDialogLabel" aria-hidden="true">
        <div class="modal-dialog">
            <div class="modal-content">
                <div class="modal-header py-1">
                    <h5 class="modal-title" id="modalDialogLabel"><i class="fa fa-share" aria-hidden="true"></i> Share
                    </h5>
                    <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
                </div>
                <div class="modal-body">
                    <div id="downloads" style="display: none">
                        <div class="d-grid gap-2 down-list" data-lang="@lang('Download')">
                            <div class="visually-hidden"> {{ trans('Download Free') }} </div>
                        </div>
                    </div>
                    <div id="shares" style="display: none">
                        <div class="d-flex flex-wrap justify-content-center share" data-lang="@lang('Share')">
                            <a href="#" class="fb"
                                data-href="https://www.facebook.com/sharer/sharer.php?u=(url)"><i class="fa fa-facebook"
                                    aria-hidden="true"></i></a>
                            <a href="#" class="tw"
                                data-href="https://www.twitter.com/share?text=(title)&url=(url)"><i class="fa fa-twitter"
                                    aria-hidden="true"></i></a>
                            <a href="#" class="mashare" data-href="mailto:body=(title)%0A(url)"><i
                                    class="fa fa-mail" aria-hidden="true"></i></a>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>
@endsection

@push('scripts')
    <script>
        document.addEventListener('DOMContentLoaded', () => {
            const player = new Plyr('#myplayer');
            player.source = @json($player_data);
        });
    </script>
@endpush
