<!DOCTYPE html>
<html lang="{{ str_replace('_', '-', app()->getLocale()) }}">
<head>
{!! setting('head_code') !!}
{!! Meta::toHtml() !!}
<link media="all" type="text/css" rel="stylesheet" href="{{ isDarkMode() ? asset('css/dark.css') : asset('css/light.css') }}">
@yield('head')
</head>
<body>
    <header>
        <nav class="navbar sticky-top navbar-expand-lg navbar-dark shadow-sm">
            <div class="container">
                <a class="navbar-brand py-0" href="{{ config('app.url') }}">
                    @if ($logo = setting('logo'))
                        <img src="{{ asset($logo['path']) }}" width="{{ $logo['w'] }}" height="{{ $logo['h'] }}"
                            alt="logo">
                    @else
                        <img src="{{ asset('images/logo.png') }}" width="121" height="40" alt="logo">
                    @endif
                </a>
                <button class="navbar-toggler" type="button" data-bs-toggle="collapse"
                    data-bs-target="#navbarSupportedContent" aria-controls="navbarSupportedContent"
                    aria-expanded="false" aria-label="Toggle navigation">
                    <span class="navbar-toggler-icon"></span>
                </button>
                <div class="collapse navbar-collapse" id="navbarSupportedContent">
                    <div
                        class="ms-auto d-flex flex-wrap align-items-center justify-content-center justify-content-lg-start">
                        <ul class="nav col-12 col-lg-auto me-lg-auto mb-2 justify-content-center mb-md-0">
                            <li>{!! link_to_route('home', __('Home'), null, ['class' => 'nav-link px-2 text-light']) !!}</li>
                            @if (Route::has('videos.all'))
                                <li>{!! link_to_route('videos.all', __('Videos'), null, ['class' => 'nav-link px-2 text-white']) !!}</li>
                            @endif

                            @if (Route::has('category.all'))
                                <li>{!! link_to_route('category.all', __('Categories'), null, ['class' => 'nav-link px-2 text-white']) !!}</li>
                            @endif

                            @if (Route::has('playlists.all'))
                                <li>{!! link_to_route('playlists.all', __('Playlists'), null, ['class' => 'nav-link px-2 text-white']) !!}</li>
                            @endif

                            @if (Route::has('topvideos.all'))
                                <li>{!! link_to_route('topvideos.all', __('Top Videos'), null, ['class' => 'nav-link px-2 text-white']) !!}</li>
                            @endif

                            @if ($pages = cache()->get('pages.all'))
                                <li class="nav-item dropdown">
                                    <a class="nav-link text-white dropdown-toggle" href="#"
                                        id="navbarScrollingDropdown" role="button" data-bs-toggle="dropdown"
                                        aria-expanded="false">
                                        {{ trans('Pages') }}
                                    </a>
                                    <ul class="dropdown-menu" aria-labelledby="navbarScrollingDropdown">
                                        @foreach ($pages as $name => $link)
                                            <li><a class="dropdown-item"
                                                    href="{{ $link }}">{{ $name }}</a></li>
                                        @endforeach
                                    </ul>
                                </li>
                            @endif
                        </ul>
                    </div>
                </div>
            </div>
        </nav>
    </header>
    @yield('content')
    <footer>
        <div class="bg">
            <div class="container">
                <div class="d-flex justify-content-center">
                    <div class="fs-5">
                        &copy; <a class="text-white" href="{{ config('app.url') }}">
                            {{ config('app.name') }}</a>
                    </div>
                </div>
            </div>
        </div>
    </footer>
    <script>
        window.app = {
            url: "{{ config('app.url') }}",
            player: {
                isInlinePlayer: {{ isInlinePlayer() ? 'true' : 'false' }},
                defaultOptions: {
                    loadSprite: true,
                    ratio: "16:9",
                    iconUrl: "{{ asset('static/plyr.svg') }}",
                    blankVideo: "{{ asset('static/blank.mp4') }}",
                    quality: @json(FrontConst::PLAYER_DEFAULT_QUALITY)
                }
            }
        }

        if ('serviceWorker' in navigator) {
            window.addEventListener('load', function() {
                navigator.serviceWorker.register('/sw.js')
                    .then(reg => {
                        console.log('Service worker registered! 😎', reg);
                    })
                    .catch(err => {
                        console.log('😥 Service worker registration failed: ', err);
                    });
            });
        }
    </script>

    {!! Meta::footer()->toHtml() !!}
    <script src="{{ asset('js/app.js') }}" defer></script>
    @stack('scripts')
    {!! setting('footer_code') !!}
</body>

</html>
