@extends('installer.layout')
@section('content')
    <div class="card shadow-lg">
        <div class="card-body">
            
            <div class="position-relative m-4">
                <div class="progress" style="height: 1px;">
                    <div class="progress-bar" role="progressbar" style="width: 66%;" aria-valuenow="0" aria-valuemin="0"
                        aria-valuemax="100"></div>
                </div>
                <div class="position-absolute top-0 start-0 translate-middle btn btn-sm btn-primary rounded-pill"
                    style="width: 2rem; height:2rem;">1</div>
                <div class="position-absolute top-0 translate-middle btn btn-sm btn-primary rounded-pill"
                    style="width: 2rem; height:2rem;left:32%">2</div>
                <div class="position-absolute top-0 translate-middle btn btn-sm btn-primary rounded-pill"
                    style="width: 2rem; height:2rem;left:66%">3</div>
                <div class="position-absolute top-0 start-100 translate-middle btn btn-sm btn-secondary rounded-pill"
                    style="width: 2rem; height:2rem;">4</div>
            </div>

            <h4 class="card-title text-primary">{{ __('Configuration') }}</h4>
            <p class="card-text">
                {{ __('Please enter configuration values carefully or else it could result in installation failure.') }}
            </p>

            @if ($errors->any() || session('error'))
                <div class="alert alert-warning alert-dismissible fade show" role="alert">
                    @if ($errors->any())
                        <ul>
                            @foreach ($errors->all() as $error)
                                <li>{{ $error }}</li>
                            @endforeach
                        </ul>
                    @else
                        <p>{{ session('error') }}</p>
                    @endif
                    <button type="button" class="btn-close" data-bs-dismiss="alert" aria-label="Close"></button>
                </div>
            @endif
        </div>

        {!! Form::open(['route' => 'installer.post.configuration', 'method' => 'POST', 'files' => true]) !!}

        <div class="card-body">

            <h4>@lang('Information')</h4>
            <hr>
            <div class="row">

                <div class="col-md-8">
                    <div class="form-group">
                        <label for="configure-user-name">
                            {{ __('Your Name') }} <span class="text-danger">&ast;</span>
                        </label>
                        <input type="text" class="form-control @error('USER_NAME') is-invalid @enderror"
                            id="configure-user-name" name="USER_NAME" required value="{{ old('USER_NAME') }}">

                        @error('USER_NAME')
                            <div class="invalid-feedback">{{ $message }}</div>
                        @enderror
                    </div>
                </div>

                <div class="col-md-8">
                    <div class="form-group">
                        <label for="configure-email-name">
                            {{ __('Your Email') }} <span class="text-danger">&ast;</span>
                        </label>
                        <input type="email" class="form-control @error('USER_EMAIL') is-invalid @enderror"
                            id="configure-email-name" name="USER_EMAIL" required value="{{ old('USER_EMAIL') }}">
                        @error('USER_EMAIL')
                            <div class="invalid-feedback">{{ $message }}</div>
                        @enderror
                    </div>
                </div>

                <div class="col-md-8">
                    <div class="form-group">
                        <label for="configure-license-attachment">
                            {{ __('Attachment') }} <span class="text-danger">&ast;</span>
                        </label>
                        <input type="file" class="form-control @error('USER_ATTACHMENT') is-invalid @enderror"
                            id="configure-license-attachment" name="USER_ATTACHMENT" required>
                        @error('USER_ATTACHMENT')
                            <div class="invalid-feedback">{{ $message }}</div>
                        @enderror
                        <small
                            class="form-text text-muted">{{ __('Attach Only Purchase Receipt, License Copy, Invoice.') }}</small>
                    </div>
                </div>

            </div>
            <br>
            <h4>{{ trans('General') }}</h4>
            <hr>
            <div class="row">
                <div class="col-md-8">
                    <div class="form-group">
                        <label for="configure-app-name">
                            {{ __('Name') }} <span class="text-danger">&ast;</span>
                        </label>
                        <input type="text" class="form-control @error('APP_NAME') is-invalid @enderror"
                            id="configure-app-name" name="APP_NAME" required
                            value="{{ old('APP_NAME', config('app.name')) }}">
                        @error('APP_NAME')
                            <div class="invalid-feedback">{{ $message }}</div>
                        @enderror
                        <small
                            class="form-text text-muted">{{ __('This is the name of the app shown everywhere in admin panel and outgoing emails.') }}</small>
                    </div>
                    <div class="form-group">
                        <label for="configure-app-url">
                            {{ __('URL') }} <span class="text-danger">&ast;</span>
                        </label>
                        <input type="text" class="form-control @error('APP_URL') is-invalid @enderror"
                            id="configure-app-url" name="APP_URL" required
                            value="{{ old('APP_URL', rtrim(url('/'), '/')) }}">
                        @error('APP_URL')
                            <div class="invalid-feedback">{{ $message }}</div>
                        @enderror
                    </div>
                    <div class="form-group mb-md-0">
                        <label for="configure-app-timezone">
                            {{ __('Timezone') }} <span class="text-danger">&ast;</span>
                        </label>
                        <select class="form-control @error('APP_TIMEZONE') is-invalid @enderror" id="configure-app-timezone"
                            name="APP_TIMEZONE" required>
                            @php
                                $old_timezone = old('APP_TIMEZONE', config('app.timezone'));
                            @endphp
                            @foreach ($timezones as $key => $timezone)
                                <option value="{{ $key }}" @if ($key == $old_timezone) selected @endif>
                                    {{ $timezone }}</option>
                            @endforeach
                        </select>
                        @error('APP_TIMEZONE')
                            <div class="invalid-feedback">{{ $message }}</div>
                        @enderror
                    </div>
                </div>
            </div>

            <br>
            <h4>{{ trans('Database') }}</h4>
            <hr>
            <div class="row">
                <div class="col-md-8">
                    <div class="form-group">
                        <label for="configure-db-host">
                            {{ __('Database host & port') }} <span class="text-danger">&ast;</span>
                        </label>
                        <div class="input-group @if ($errors->has('DB_HOST') || $errors->has('DB_PORT')) is-invalid @endif">
                            <input type="text" class="form-control @error('DB_HOST') is-invalid @enderror"
                                id="configure-db-host" name="DB_HOST" required
                                value="{{ old('DB_HOST', config('database.connections.mysql.host')) }}">
                            <input class="form-control @error('DB_PORT') is-invalid @enderror" id="configure-db-port"
                                name="DB_PORT" required type="number"
                                value="{{ old('DB_PORT', config('database.connections.mysql.port')) }}">
                        </div>
                        @error('DB_HOST')
                            <div class="invalid-feedback">{{ $message }}</div>
                        @enderror
                        @error('DB_PORT')
                            <div class="invalid-feedback">{{ $message }}</div>
                        @enderror
                    </div>
                    <div class="form-group">
                        <label for="configure-db-database">
                            {{ __('Database name') }} <span class="text-danger">&ast;</span>
                        </label>
                        <input type="text" class="form-control @error('DB_DATABASE') is-invalid @enderror"
                            id="configure-db-database" name="DB_DATABASE" required
                            value="{{ old('DB_DATABASE', config('database.connections.mysql.database')) }}">
                        @error('DB_DATABASE')
                            <div class="invalid-feedback">{{ $message }}</div>
                        @enderror
                    </div>
                    <div class="form-group mb-0">
                        <label for="configure-db-username">
                            {{ __('Database username & password') }} <span class="text-danger">&ast;</span>
                        </label>
                        <div class="input-group @if ($errors->has('DB_USERNAME') || $errors->has('DB_PASSWORD')) is-invalid @endif">
                            <input type="text" class="form-control @error('DB_USERNAME') is-invalid @enderror"
                                id="configure-db-username" name="DB_USERNAME" required
                                value="{{ old('DB_USERNAME', config('database.connections.mysql.username')) }}">
                            <input class="form-control @error('DB_PASSWORD') is-invalid @enderror"
                                id="configure-db-password" name="DB_PASSWORD" type="text">
                        </div>
                        @error('DB_USERNAME')
                            <div class="invalid-feedback">{{ $message }}</div>
                        @enderror
                        @error('DB_PASSWORD')
                            <div class="invalid-feedback">{{ $message }}</div>
                        @enderror
                    </div>
                </div>
            </div>
            <hr>

            <div class="d-flex justify-content-between">
                <a href="{{ route('installer.index') }}" class="btn btn-dark"><i class="fa fa-caret-left"></i>
                    {{ trans('Back') }}</a>
                <button type="submit" class="btn btn-primary ms-auto"><i class="fa fa-ok-circled"></i>
                    {{ trans('Continue') }}</button>
            </div>

            <div class="clearfix"></div>
        </div>

        {!! Form::close() !!}
    </div>
@endsection
