<?php

use App\Http\Controllers\Backend\Actions\DeleteController;
use App\Http\Controllers\Backend\Users\UserController;
use App\Http\Controllers\Backend\Users\RoleController;
use App\Http\Controllers\Backend\Categories\CategoryController;
use App\Http\Controllers\Backend\Home\DashboardController;
use App\Http\Controllers\Backend\Pages\PageController;
use App\Http\Controllers\Backend\Playlist\PlaylistController;
use App\Http\Controllers\Backend\Playlist\PlaylistVideoController;
use  App\Http\Controllers\Backend\Settings\SettingController;
use App\Http\Controllers\Backend\Videos\MultipleUploadController;
use App\Http\Controllers\Backend\Videos\VidController;
use App\Http\Controllers\Backend\Videos\VideoController;
use App\Http\Controllers\Backend\Videos\YoutubeUploadController;

Route::get('/', [DashboardController::class, 'index'])->name('dashboard');
Route::get('clearcache', [DashboardController::class, 'cacheClear'])->name('dashboard.clearcache');
Route::get("statistics", [DashboardController::class, 'statistics'])->name('dashboard.statistics');
Route::get('editprofile', [DashboardController::class, 'profilechange'])->name('users.editprofile');
Route::put('editprofile', [DashboardController::class, 'profilestore'])->name('users.profilestore');
Route::get('profile', [DashboardController::class, 'profileView'])->name('users.profile');
Route::resource('users', UserController::class);
Route::resource('roles', RoleController::class);
Route::resource('videos', VidController::class);
Route::resource('category', CategoryController::class);
Route::resource('playlists', PlaylistController::class);
Route::resource('pages', PageController::class);
Route::get('settings', [SettingController::class, 'index'])->name('settings.index');
Route::put('settings', [SettingController::class, 'update'])->name('settings.update');

Route::prefix("delete")->name("delete.multiple.")->group(function () {
  Route::delete("videos", [DeleteController::class, 'deleteVideos'])->name('videos')->middleware("permission:videos.delete");
  Route::delete("category", [DeleteController::class, 'deleteCategories'])->name('category')->middleware("permission:category.delete");
  Route::delete("playlists", [DeleteController::class, 'deletePlaylists'])->name('playlilsts')->middleware("permission:playlists.delete");
  Route::delete("users", [DeleteController::class, 'deleteUsers'])->name('users')->middleware("permission:users.delete");
  Route::delete("roles", [DeleteController::class, 'deleteRoles'])->name('roles')->middleware("permission:roles.delete");
  Route::delete("pages", [DeleteController::class, 'deletePages'])->name('pages')->middleware("permission:pages.delete");
});

Route::name('upload.')->prefix("upload")->group(function () {
  Route::get("add-from-youtube", [YoutubeUploadController::class, 'index'])->name('addyoutube');
  Route::post("add-from-youtube", [YoutubeUploadController::class, 'upload'])->name('addyoutube.store');
  Route::get("multiple", [MultipleUploadController::class, 'index'])->name('multiple');
  Route::post("multiple", [MultipleUploadController::class, 'upload'])->name('multiple.store');
  Route::post("multiple-uploader", [MultipleUploadController::class, 'uploadLargeFiles'])->name('uploader');
  Route::delete("fm-delete", [MultipleUploadController::class, 'fmDelete'])->name('fileDelete');
});

Route::post('addvideoplaylist', [PlaylistVideoController::class, 'addVideoPlaylist'])->name('add.video.playlist');
Route::delete('removevideoplaylist', [PlaylistVideoController::class, 'removeVideoPlaylist'])->name('remove.video.playlist');
Route::get('playlistvideosadd', [PlaylistVideoController::class, 'videoList']);
Route::get('playlists-json', [PlaylistVideoController::class, 'playlistList']);
Route::get('tempimage', [DashboardController::class, 'tempImage']);

