<?php

use App\Http\Controllers\Frontend\PlaylistController;
use App\Http\Controllers\Frontend\CategoryController;
use App\Http\Controllers\Frontend\HomeController;
use App\Http\Controllers\Frontend\InstallerController;
use App\Http\Controllers\Frontend\VideoController;
use Illuminate\Support\Facades\Route;

/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web routes for your application. These
| routes are loaded by the RouteServiceProvider within a group which
| contains the "web" middleware group. Now create something great!
|
*/
//Authencation Routing
Auth::routes(['register' => false]);

Route::prefix("installer")->name('installer.')->group(function () {
    Route::get('/', [InstallerController::class, "index"])->name("index");
    Route::get('requirement', [InstallerController::class, "requirement"])->name("requirement");
    Route::get("configuration", [InstallerController::class, 'configuration'])->name('configuration');
    Route::post('configuration', [InstallerController::class, 'postConfiguration'])->name('post.configuration');
    Route::post("finish", [InstallerController::class, 'finish'])->name("finish");
});



// Home Routing
Route::get('/', [HomeController::class, 'index'])->name('home');

Route::get('pages/{slug}', [HomeController::class, 'pageInfo'])->name('page.info');
Route::get('searchquery', [HomeController::class, 'getSearchIndex'])->name('search.index');

// Videos Routing
Route::prefix(setting("route_videos_prefix", "videos"))->name('videos.')->group(function () {
    Route::get('/', [VideoController::class, 'videos'])->name("all");
});

//Categories Routing
Route::prefix(setting('route_categories_prefix', "categories"))->name("category.")->group(function () {
    Route::get('/', [CategoryController::class, 'category'])->name("all");
});

//Subcategories Routing
Route::prefix(setting('route_subcategory_prefix', "category"))->name("subcategory.")->group(function () {
    Route::get('{slug}', [CategoryController::class, 'subCategory'])->name("all");
});

//Playlist Routing
Route::prefix(setting('route_playlists_prefix', "playlists"))->name("playlists.")->group(function () {
    Route::get('/', [PlaylistController::class, 'playlist'])->name("all");
});

//Top Routing
Route::prefix(setting("route_top_videos_prefix", "topvideos"))->name("topvideos.")->group(function () {
    Route::get('/', [VideoController::class, 'top'])->name("all");
});

// Videos by Category
Route::prefix(setting('route_category_videos_prefix', "vlist"))->name("categoryvideos.")->group(function () {
    Route::get('{slug}', [CategoryController::class, 'categoryVideos'])->name("all");
});

//Videos by Playlist
Route::prefix(setting('route_playlists_videos_prefix', "list"))->name("playlistvideos.")->group(function () {
    Route::get('{slug}', [PlaylistController::class, 'playlistVideos'])->name("all");
});


//Video Info Page
Route::prefix(setting('route_video_page_prefix', 'v'))->group(function () {
    Route::post("links/{slug}", [VideoController::class, 'getLinks'])->name("video.links");
    Route::post("downloads/{slug}", [VideoController::class, 'downloads'])->name("video.downloads");
    Route::get("download/{uuid}", [VideoController::class, "download"])->name("video.download")->middleware("signed");
    Route::post("like/{slug}", [VideoController::class, 'videoLike'])->name("video.like");
    Route::post("unlike/{slug}", [VideoController::class, 'videoUnlike'])->name("video.unlike");
    Route::get('{slug}', [VideoController::class, 'video'])->name("video.page");
    Route::get('releted/{slug}', [VideoController::class, 'moreReletedVideos'])->name('video.releted');
});

Route::prefix(setting('route_video_by_tags_prefix', "tags"))->name('tags.')->group(function () {
    Route::get('{slug}', [VideoController::class, 'tagVideos'])->name("all");
});

Route::prefix(setting('route_search_page_prefix', "search"))->name('search.')->group(function () {
    Route::get('/', [VideoController::class, 'searchVideos'])->name("videos");
});
