$(function () {

    const ROLES = "roles";
    const USERS = "users";
    const SUPER_ADMIN = "Super Admin";

    const ADD_VIDEO_PLAYLIST = "addvideoplaylist";
    const REMOVE_VIDEO_PLAYLIST = "removevideoplaylist";

    $.contextMenu({
        selector: '.row-context-menu',
        callback: function (key, options) {
            let id = $(this).closest('tr').attr('id');
            ActionMenu(id, key);
        },
        items: app.rowContext
    });


    function ActionMenu(id, key) {
        if (key == "show" || key == "detail") {
            if (checkPermission(id)) {
                if (key == "detail") {
                    ShowDetail(id);
                } else {
                    ShowRow(id);
                }
            } else {
                AlertDenied("view info");
            }
        }
        if (key == "delete") {
            if (checkPermission(id)) {
                DeleteRow(id);
            } else {
                AlertDenied(key);
            }
        }
        if (key == "edit") {
            if (checkPermission(id)) {
                EditRow(id);
            } else {
                AlertDenied(key);
            }
        }
        if (key == "selectall") {
            SelectAllRow();

        }
        if (key == "deselectall") {
            DeSelectAllRow();
        }

        if (key == "deleteall") {
            DeleteAllRow();
        }

        if (key == "remove_video_playlist") {
            selectedVideoPlaylist("remove");
        }

        if (key == "add_video_playlist") {
            addVideosPlaylist()
        }


        if (key == "reload") {
            localStorage.removeItem("DataTables_datalist_" + location.pathname);
            window.location.reload();
        }


    }



    $("body").on("dblclick", ".explore-info", function (e) {
        e.preventDefault;
        let id = $(this).closest('tr').attr('id');
        ShowRow(id);
    });

    function AlertDenied(action) {
        swal('Denied', "You have does not have any permission to " + action + "!", 'warning');
    }

    function checkPermission(id) {
        let Table = $("#datalist");
        if (Table.attr("name") == ROLES) {
            let rolename = Table.DataTable().row("#" + id).data().name;
            if (rolename == SUPER_ADMIN) {
                return false;
            }
        }

        if (Table.attr("name") == USERS) {
            let rolesData = Table.DataTable().row("#" + id).data().roles;
            let roles = [];
            $.each(rolesData, function (i, d) {
                roles.push(d.name);
            });
            if (app.authId != id && app.isSuperAdmin != "Y" && roles.includes(SUPER_ADMIN)) {
                return false;
            }
        }
        return true;
    }

    function ShowRow(id) {
        let InfoURL = $("#datalist").attr('name');
        window.location.replace(InfoURL + '/' + id);
    }

    function ShowDetail(id) {
        let InfoURL = $("#datalist").attr('name');
        window.location.replace('../' + InfoURL + '/' + id);
    }

    function SelectAllRow() {
        $("#datalist").DataTable().rows().select();
    }

    function DeSelectAllRow() {
        $("#datalist").DataTable().rows().deselect();
    }

    function DeleteAllRow() {
        ids = $("#datalist").DataTable().rows({ selected: true }).ids().toArray();
        deleteRequest(ids)
        console.log(ids);
    };

    function selectedVideoPlaylist(action) {
        let ids = $("#datalist").DataTable().rows({ selected: true }).ids().toArray();
        if (ids.length < 1) {
            swal('Error!', "Please Select first", 'warning');
            return false;
        }
        let type, url, playlistId;
        if (action == "remove") {
            type = "DELETE";
            url = '../' + REMOVE_VIDEO_PLAYLIST;
            playlistId = $("#datalist").data('playlist');
        } else {
            type = "POST";
            url = ADD_VIDEO_PLAYLIST;
            playlistId = $("#playlist_Id").val();
        }


        $.ajax({
            type: type,
            url: url,
            dataType: "json",
            data: {
                playlist_id: playlistId,
                video_ids: ids
            }
        }).done(function (resp) {
            if (resp.status == true) {
                if (action == "remove") {
                    $("#datalist").DataTable().draw();
                } else {
                    $('#addVideoPlaylistModal').modal("hide");
                    $("#datalist").DataTable().rows().deselect();
                }
                setTimeout(() => {
                    swal('Success!', resp.message, 'success');
                }, 600);
            } else {
                swal('Error!', resp.message, 'warning');
            }

        });
    }

    function addVideosPlaylist() {

        if ($("#datalist").DataTable().rows({ selected: true }).count() < 1) {
            swal('Error!', "Please Select first", 'warning');
            return false;
        }
        $('#addVideoPlaylistModal').modal({
            backdrop: "static",
            keyboard: false
        });
    }


    $('.addplaylist-video').on("click", function () {
        selectedVideoPlaylist("add");
    });

    function EditRow(id) {
        let EditURL = $("#datalist").attr('name');
        window.location.replace(EditURL + '/' + id + "/edit");
    }

    function DeleteRow(id) {
        swal({
            title: "Are you sure to delete?",
            text: "Id: " + id + "\n You will not be able to recover this!",
            type: "warning",
            showCancelButton: true,
            cancelButtonClass: "btn-warning",
            confirmButtonClass: "btn-danger",
            confirmButtonText: "Yes, delete it!",
            cancelButtonText: "No, cancel!",
            closeOnConfirm: false,
            closeOnCancel: false,
            showLoaderOnConfirm: true
        },
            function (isConfirm) {
                if (isConfirm) {
                    $.ajax({
                        type: 'POST',
                        url: $("#datalist").attr('name') + "/" + id,
                        dataType: "json",
                        data: {
                            _method: 'DELETE',
                        },
                        success: function (res) {
                            if (res.status == true) {
                                $("#datalist").DataTable().draw();
                                swal('Successfully', res.message, 'success');
                            } else {
                                swal('Error!', res.message, 'warning');
                            }
                        }
                    });
                } else {
                    swal.close();
                }
            });
    }

    function deleteRequest(ids) {
        swal({
            title: "Are you sure to delete?",
            text: "Total: " + ids.length + "\n You will not be able to recover this!",
            type: "warning",
            showCancelButton: true,
            cancelButtonClass: "btn-warning",
            confirmButtonClass: "btn-danger",
            confirmButtonText: "Yes, delete it!",
            cancelButtonText: "No, cancel!",
            closeOnConfirm: false,
            closeOnCancel: false,
            showLoaderOnConfirm: true
        },
            function (isConfirm) {
                if (isConfirm) {
                    $.ajax({
                        type: 'POST',
                        url: "delete/" + $("#datalist").attr('name'),
                        dataType: "json",
                        data: {
                            _method: 'DELETE',
                            ids: ids
                        },
                        success: function (res) {
                            if (res.status == true) {
                                $("#datalist").DataTable().draw();
                                swal('Successfully', res.message, 'success');
                            } else {
                                swal('Error!', res.message, 'warning');
                            }
                        }
                    });
                } else {
                    swal.close();
                }
            });
    }
});